@@ -3,9 +3,9 @@
 <link rel="stylesheet" href="layersmenu.css" type="text/css">
 <title>Dynamic JavaScript Layers Menu</title>
 
-<? include ("layersmenu-header.php"); ?>
+<? include ("layersmenu-header.inc.php"); ?>
 
-<head>
+</head>
 
 <body bgcolor="#ffffff" marginheight=0 marginwidth=0 topmargin=0 leftmargin=0>
 <table border=0 cellpadding=8 cellspacing=0 width="100%">
@@ -19,7 +19,7 @@
 </tr>
 </table>
 
-<? include ("layersmenu-footer.php"); ?>
+<? include ("layersmenu-footer.inc.php"); ?>
 
 </body>
 </html>
