@@ -191,12 +191,19 @@ function print_edit_category_form($id) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the category */
-	$qid = db_query("
-	SELECT name, special_level, description, parent_id
-	FROM categories
-	WHERE id = '$id'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT name, special_level, description, parent_id
+		FROM categories
+		WHERE id = '$id'
 	");
-	$frm = db_fetch_array($qid, 0);
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["name"] = $qid->f("name");
+	$frm["special_level"] = $qid->f("special_level");
+	$frm["description"] = $qid->f("description");
+	$frm["parent_id"] = $qid->f("parent_id");
 
 	/* set values for the form */
 	$frm["parent"] = array($frm["parent_id"]);
@@ -218,28 +225,34 @@ function delete_category($id) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	/* find the parent of this category */
-	$qid = db_query("
-	SELECT cat.name, cat.parent_id, parent.name AS parent
-	FROM categories cat, categories parent
-	WHERE parent.id = cat.parent_id
-		AND cat.id = '$id'
+//	$qid = db_query("
+	$qid->Query("
+		SELECT cat.name, cat.parent_id, parent.name AS parent
+		FROM categories cat, categories parent
+		WHERE parent.id = cat.parent_id
+			AND cat.id = '$id'
 	");
-	$cat = db_fetch_object($qid, 0);
+//	$cat = db_fetch_object($qid, 0);
+	$qid->next_record();
+	$cat->name = $qid->f("name");
+	$cat->parent_id = $qid->f("parent_id");
+	$cat->parent = $qid->f("parent");
 
 	/* delete this category */
-	$qid = db_query("
-	DELETE FROM categories
-	WHERE id = '$id'
-	");
+//	$qid = db_query("
+	$qid->Query("DELETE FROM categories WHERE id = '$id'");
 
 	// delete products in this category that also belong
 	// to the parent category, to avoid duplicates forbidden
 	// by the primary key constraint
 /* Nested queries aren't still supported by MySQL :(
- *	$qid = db_query("
+ *	//$qid = db_query("
+ *	$qid->Query("
  *		DELETE FROM products_categories WHERE ( product_id,category_id ) IN (
  *			SELECT * FROM products_categories pc WHERE category_id = '$id' AND
  *			EXISTS (
@@ -250,7 +263,8 @@ function delete_category($id) {
  *		)
  *	");
  * a workaround in the following */
-	$qid = db_query("
+//	$qid = db_query("
+	$qid->Query("
 		SELECT pc1.product_id
 		FROM products_categories pc1 , products_categories pc2
 		WHERE
@@ -258,35 +272,42 @@ function delete_category($id) {
 			AND pc1.category_id = '$cat->parent_id'
 			AND pc2.category_id = '$id'
 	");
-	if (($numr = db_num_rows($qid)) > 0) {
+	if (($numr = $qid->num_rows()) > 0) {
 		$toberemoved = "";
 		for ($i=0; $i<$numr-1; $i++) {
-			$appoggio = db_fetch_object($qid, $i);
-			$toberemoved .= "'" . $appoggio->product_id . "', ";
+//			$appoggio = db_fetch_object($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$toberemoved .= "'" . $qid->f("product_id") . "', ";
 		}
-		$appoggio = db_fetch_object($qid, $numr-1);
-		$toberemoved .= "'" . $appoggio->product_id . "'";
-		$qid = db_query("
+//		$appoggio = db_fetch_object($qid, $numr-1);
+		$qid->next_record();
+		$toberemoved .= "'" . $qid->f("product_id") . "'";
+//		$qid = db_query("
+		$qid->Query("
 			DELETE FROM products_categories
 			WHERE category_id = '$id' AND product_id IN ($toberemoved)
 		");
 	}
 
 	/* re-assign all the products in this category to the parent category */
-	$qid = db_query("
-	UPDATE products_categories
-	SET category_id = $cat->parent_id
-	WHERE category_id = '$id'
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE products_categories
+		SET category_id = $cat->parent_id
+		WHERE category_id = '$id'
 	");
 
 	/* re-assign all sub categories of this category to the parent category */
-	$qid = db_query("
-	UPDATE categories
-	SET parent_id = $cat->parent_id
-	WHERE parent_id = '$id'
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE categories
+		SET parent_id = $cat->parent_id
+		WHERE parent_id = '$id'
 	");
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -317,9 +338,11 @@ function insert_subcategory($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	INSERT INTO categories (parent_id, name, special_level, description)
-	VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO categories (parent_id, name, special_level, description)
+		VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -349,13 +372,15 @@ function update_category($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	UPDATE categories SET
-		 parent_id = '$frm[parent]'
-		,name = '$frm[name]'
-		,special_level = '$frm[special_level]'
-		,description = '$frm[description]'
-	WHERE id = '$id'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE categories SET
+			 parent_id = '$frm[parent]'
+			,name = '$frm[name]'
+			,special_level = '$frm[special_level]'
+			,description = '$frm[description]'
+		WHERE id = '$id'
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -385,15 +410,25 @@ function print_category_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT cat.id, cat.name, cat.special_level, cat.description, parent.name AS parent
-		FROM categories cat, categories parent
-		WHERE parent.id = cat.parent_id AND cat.id > 1 ORDER BY cat.name
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT cat.id, cat.name, cat.special_level, cat.description, parent.name AS parent
+			FROM categories cat, categories parent
+			WHERE parent.id = cat.parent_id AND cat.id > 1 ORDER BY cat.name
 		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["categories"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["categories"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["categories"][$i]["id"] = $qid->f("id");
+			$SESSION["categories"][$i]["name"] = $qid->f("name");
+			$SESSION["categories"][$i]["special_level"] = $qid->f("special_level");
+			$SESSION["categories"][$i]["description"] = $qid->f("description");
+			$SESSION["categories"][$i]["parent"] = $qid->f("parent");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -468,11 +503,13 @@ function print_import_category_form() {
 function import_category($userfile) {
 /* Import categories from a text file */
 	global $CFG, $ME, $SESSION;
-//	include ($CFG->globalerror);
+	include ($CFG->globalerror);
 	$errors = new Object;
 
 //	/* Let's open a transaction */
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	$fcontents = file ($userfile);
 	/* Traverse the file */
@@ -489,46 +526,54 @@ function import_category($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the parent category exists ... */
-		$qid = db_query("
-		SELECT id FROM categories WHERE name = '$fldarr[0]'
+//		$qid = db_query("
+		$qid->Query("
+			SELECT id FROM categories WHERE name = '$fldarr[0]'
 		");
-		if (db_num_rows($qid) == 0) {
+//		if (db_num_rows($qid) == 0) {
+		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's return an error ... */
 			echo $line_num . $Err_ImpCat . $fldarr[0] . "'.<br>";
 		} else {
 			/* ... otherwise let's save its ID ... */
-			$arr = db_fetch_array($qid,0);
-			$pid = $arr[0];
+//			$arr = db_fetch_array($qid,0);
+//			$pid = $arr[0];
+			$qid->next_record();
+			$pid = $qid->f("id");
 
 			/* ... and let's see if the category already exists ... */
-			$qid = db_query("
-			SELECT id FROM categories WHERE name = '$fldarr[1]'
-			");
-			if (db_num_rows($qid) == 0) {
+//			$qid = db_query("
+			$qid->Query("SELECT id FROM categories WHERE name = '$fldarr[1]'");
+//			if (db_num_rows($qid) == 0) {
+			if ($qid->num_rows() == 0) {
 				/* ... if it doesn't exist let's create it ... */
-				$qid = db_query("
-				INSERT INTO categories (parent_id, name, special_level, description)
-				VALUES ('$pid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
+//				$qid = db_query("
+				$qid->Query("
+					INSERT INTO categories (parent_id, name, special_level, description)
+					VALUES ('$pid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
 				");
 			} else {
 				/* ... otherwise let's save its ID ... */
-				$arr = db_fetch_array($qid,0);
-				$sid = $arr[0];
+//				$arr = db_fetch_array($qid,0);
+//				$sid = $arr[0];
+				$qid->next_record();
+				$sid = $qid->f("id");
 				/* ... and update ... */
-				$qid = db_query("
-				UPDATE categories SET
-	 				parent_id = '$pid'
-					,name = '$fldarr[1]'
-					,special_level = '$fldarr[2]'
-					,description = '$fldarr[3]'
-				WHERE id = '$sid'
+//				$qid = db_query("
+				$qid->Query("
+					UPDATE categories SET
+						parent_id = '$pid'
+						,special_level = '$fldarr[2]'
+						,description = '$fldarr[3]'
+					WHERE id = '$sid'
 				");
 			}
 		}
 	}
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
