@@ -22,14 +22,16 @@ include("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new DB_Sql;
+
 /* form has been submitted, check if it the user login information is correct */
 if (match_referer() && isset($HTTP_POST_VARS)) {
 	$frm = $HTTP_POST_VARS;
-	$errormsg = validate_form($frm, $errors);
+	$errormsg = validate_form(&$qid, $frm, $errors);
 
 	if (empty($errormsg)) {
-		update_user_password($frm["newpassword"], $frm["username"]);
-		$noticemsg = $Password_Change_Successful;
+		update_user_password(&$qid, $frm["newpassword"], $frm["username"]);
+		$noticemsg = "Password_Change_Successful";
 	}
 }
 
@@ -57,7 +59,7 @@ include("$CFG->dirroot"."/footer.php");
  * FUNCTIONS
  *****************************************************************************/
 
-function validate_form(&$frm, &$errors) {
+function validate_form(&$qid, &$frm, &$errors) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
@@ -70,7 +72,7 @@ function validate_form(&$frm, &$errors) {
 		$errors->oldpassword = true;
 		$msg .= $no_old_password;
 
-	} elseif (! password_valid($frm["oldpassword"], $frm["username"])) {
+	} elseif (! password_valid(&$qid, $frm["oldpassword"], $frm["username"])) {
 		$errors->oldpassword = true;
 		$msg .= $old_password_not_valid;
 
@@ -91,25 +93,34 @@ function validate_form(&$frm, &$errors) {
 	return $msg;
 }
 
-function password_valid($password, $username) {
+function password_valid(&$qid, $password, $username) {
 /* return true if the user's password is valid */
 
 	global $SESSION;
 	
-	$qid = db_query("SELECT 1
-			FROM users
-			WHERE username = '$username' AND password = '$password'");
-	return db_num_rows($qid);
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT 1
+		FROM users
+		WHERE username = '$username' AND password = '$password'
+	");
+//	return db_num_rows($qid);
+	return $qid->num_rows();
 }
 
-function update_user_password($newpassword, $username) {
+function update_user_password(&$qid, $newpassword, $username) {
 /* set the user's password to the new one */
 
 	global $SESSION, $CFG;
 	
-	$qid = db_query("UPDATE users
-			SET password = '$newpassword'
-			WHERE username = '$username'");
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE users
+		SET password = '$newpassword'
+		WHERE username = '$username'
+	");
 
 	if (has_priv("admin")) {
 		mail(
