@@ -133,8 +133,12 @@ function print_edit_iva_form($id) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the iva percentage */
-	$qid = db_query("SELECT iva FROM iva WHERE id = '$id'");
-	$frm = db_fetch_array($qid, 0);
+	$qid = new DB_Sql;
+//	$qid = db_query("SELECT iva FROM iva WHERE id = '$id'");
+	$qid->Query("SELECT iva FROM iva WHERE id = '$id'");
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["iva"] = $qid->f("iva");
 
 	/* set values for the form */
 	$frm["newmode"] = "update";
@@ -151,21 +155,27 @@ function delete_iva($id) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	/* select the iva percentage to be deleted */
-	$qid = db_query("SELECT iva from iva WHERE id = '$id'");
-	$frm = db_fetch_array ($qid, 0);
+//	$qid = db_query("SELECT iva from iva WHERE id = '$id'");
+	$qid->Query("SELECT iva FROM iva WHERE id = '$id'");
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["iva"] = $qid->f("iva");
 
 	/* delete this iva percentage */
-	$qid = db_query("DELETE FROM iva WHERE id = '$id'");
+//	$qid = db_query("DELETE FROM iva WHERE id = '$id'");
+	$qid->Query("DELETE FROM iva WHERE id = '$id'");
 
-	// reset to 1 the iva_id for all products with this iva_id
-	$qid = db_query("
-	UPDATE products SET iva_id = 1 WHERE iva_id = '$id'
-	");
+	// reset to 0 the iva_id for all products with this iva_id
+//	$qid = db_query("
+	$qid->Query(" UPDATE products SET iva_id = 0 WHERE iva_id = '$id'");
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -192,7 +202,9 @@ function insert_iva($frm) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
+	$qid = new DB_Sql;
+//	$qid = db_query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
+	$qid->Query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -219,7 +231,9 @@ function update_iva($id, $frm) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
+	$qid = new DB_Sql;
+//	$qid = db_query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
+	$qid->Query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -248,12 +262,20 @@ function print_iva_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT id, iva FROM iva WHERE id > 0 ORDER BY iva");
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT id, iva FROM iva WHERE id > 0 ORDER BY iva
+		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["iva"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["iva"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["iva"][$i]["id"] = $qid->f("id");
+			$SESSION["iva"][$i]["iva"] = $qid->f("iva");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -328,7 +350,9 @@ function import_iva($userfile) {
 //	include ($CFG->globalerror);
 	$errors = new Object;
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	$fcontents = file ($userfile);
 	/* Traverse the file */
@@ -341,19 +365,19 @@ function import_iva($userfile) {
 		$fldarr[0] = addslashes($fldarr[0]);
 
 		/* ... and let's see if the iva percentage already exists ... */
-		$qid = db_query("
-		SELECT id FROM iva WHERE iva = '$fldarr[0]'
-		");
-		if (db_num_rows($qid) == 0) {
+//		$qid = db_query("SELECT id FROM iva WHERE iva = '$fldarr[0]'");
+		$qid->Query("SELECT id FROM iva WHERE iva = '$fldarr[0]'");
+//		if (db_num_rows($qid) == 0) {
+		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it */
-			$qid = db_query("
-			INSERT INTO iva (iva) VALUES ('$fldarr[0]')
-			");
+//			$qid = db_query("
+			$qid->Query("INSERT INTO iva (iva) VALUES ('$fldarr[0]')");
 		}
 	}
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
