@@ -140,12 +140,17 @@ function print_edit_order_state_form($id) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the order state */
-	$qid = db_query("
-	SELECT name, description
-	FROM orders_states
-	WHERE id = '$id'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT name, description
+		FROM orders_states
+		WHERE id = '$id'
 	");
-	$frm = db_fetch_array($qid, 0);
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["name"] = $qid->f("name");
+	$frm["description"] = $qid->f("description");
 
 	/* set values for the form */
 	$frm["newmode"] = "update";
@@ -163,30 +168,35 @@ function delete_order_state($id) {
 //	include ($CFG->globalerror);
 
 	if ($id > 0) {
-		$qid = db_begin();
+		$qid = new DB_Sql;
+//		$qid = db_begin();
+		$qid->begin();
 
 		/* find out this order state name */
-		$qid = db_query("
-		SELECT name FROM orders_states
-		WHERE id = '$id'
+//		$qid = db_query("
+		$qid->Query("
+			SELECT name FROM orders_states
+			WHERE id = '$id'
 		");
-		$frm = db_fetch_array($qid, 0);
+//		$frm = db_fetch_array($qid, 0);
+		$qid->next_record();
+		$frm["name"] = $qid->f("name");
 
 		/* delete this order state */
-		$qid = db_query("
-		DELETE FROM orders_states
-		WHERE id = '$id'
+//		$qid = db_query("
+		$qid->Query("
+			DELETE FROM orders_states
+			WHERE id = '$id'
 		");
 
 		// reset to 0 the state_id for all orders in this state
-		$qid = db_query("
-		UPDATE ordersca SET state_id = 0 WHERE state_id = '$id'
-		");
-		$qid = db_query("
-		UPDATE orderscc SET state_id = 0 WHERE state_id = '$id'
-		");
+//		$qid = db_query("
+		$qid->Query("UPDATE ordersca SET state_id = 0 WHERE state_id = '$id'");
+//		$qid = db_query("
+		$qid->Query("UPDATE orderscc SET state_id = 0 WHERE state_id = '$id'");
 
-		$qid = db_commit();
+//		$qid = db_commit();
+		$qid->commit();
 
 		if (empty($SESSION["goback"]["query_string"]))
 			$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -203,7 +213,8 @@ function delete_order_state($id) {
 		));
 		$t->pparse("out", "page");
 //		include("templates/order_state_deleted.ihtml");
-	} else print_orders_states_list();
+	} else
+		print_orders_states_list();
 }
 
 function insert_order_state($frm) {
@@ -217,9 +228,11 @@ function insert_order_state($frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	INSERT INTO orders_states (name, description)
-	VALUES ('$frm[name]', '$frm[description]')
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO orders_states (name, description)
+		VALUES ('$frm[name]', '$frm[description]')
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -250,11 +263,13 @@ function update_order_state($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	UPDATE orders_states SET
-		name = '$frm[name]'
-		,description = '$frm[description]'
-	WHERE id = '$id'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE orders_states SET
+			name = '$frm[name]'
+			,description = '$frm[description]'
+		WHERE id = '$id'
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
@@ -284,16 +299,24 @@ function print_orders_states_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT id, name, description
-		FROM orders_states
-		WHERE id > 0
-		ORDER BY name
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT id, name, description
+			FROM orders_states
+			WHERE id > 0
+			ORDER BY name
 		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["order_state"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["order_state"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["order_state"][$i]["id"] = $qid->f("id");
+			$SESSION["order_state"][$i]["name"] = $qid->f("name");
+			$SESSION["order_state"][$i]["description"] = $qid->f("description");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -369,7 +392,9 @@ function import_orders_states($userfile) {
 //	include ($CFG->globalerror);
 	$errors = new Object;
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	$fcontents = file ($userfile);
 	/* Traverse the file */
@@ -383,30 +408,34 @@ function import_orders_states($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* ... and let's see if the state already exists ... */
-		$qid = db_query("
-		SELECT id, name FROM orders_states WHERE name = '$fldarr[0]'
-		");
-		if (db_num_rows($qid) == 0) {
+//		$qid = db_query("
+		$qid->Query("SELECT id FROM orders_states WHERE name = '$fldarr[0]'");
+//		if (db_num_rows($qid) == 0) {
+		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it ... */
-			$qid = db_query("
-			INSERT INTO orders_states (name, description)
-			VALUES ('$fldarr[0]', '$fldarr[1]')
+//			$qid = db_query("
+			$qid->Query("
+				INSERT INTO orders_states (name, description)
+				VALUES ('$fldarr[0]', '$fldarr[1]')
 			");
 		} else {
 			/* ... otherwise let's save its ID ... */
-			$arr = db_fetch_array($qid,0);
-			$sid = $arr[0];
+//			$arr = db_fetch_array($qid,0);
+//			$sid = $arr[0];
+			$qid->next_record();
+			$sid = $qid->f("id");
 			/* ... and update ... */
-			$qid = db_query("
-			UPDATE orders_states SET
-				description = '$fldarr[1]'
-			WHERE id = '$sid'
+//			$qid = db_query("
+			$qid->Query("
+				UPDATE orders_states SET description = '$fldarr[1]'
+				WHERE id = '$sid'
 			");
 		}
 	}
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
