@@ -37,15 +37,17 @@ switch (nvl($mode)) {
 
 	case "delete" :
 		delete_order($id);
-		print_order_list();
+//		print_order_list();
 		break;
 
 	case "update" :
 		update_order($HTTP_POST_VARS);
-		print_order_list();
+//		print_order_list();
 		break;
 
 	default :
+		$SESSION["goback"]["request_uri"] = $REQUEST_URI;
+		$SESSION["goback"]["query_string"] = $QUERY_STRING;
 		print_order_list();
 		break;
 }
@@ -65,69 +67,30 @@ function show_order_details($id) {
 	global $page_number;
 //	include ($CFG->globalerror);
 
-	$qid_order = db_query("
-	SELECT o.*, os.name AS state_name
-	FROM orderscc o, orders_states os
-	WHERE o.state_id = os.id AND o.id = '$id'
+	$qid_order = new DB_Sql;
+//	$qid_order = db_query("
+	$qid_order->Query("
+		SELECT o.*, os.name AS state_name
+		FROM orderscc o, orders_states os
+		WHERE o.state_id = os.id AND o.id = '$id'
 	");
+	$qid_order->next_record();
 
-	if ($CFG->dbms == "pgsql") {
-		$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi, products p
-		WHERE	oi.product_id = p.id AND order_id = '$id'
-		UNION
-		SELECT
-			 oi.product_id
-			,'-' as name
-			,0 as curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM order_items oi
-		WHERE order_id = '$id' AND
-			NOT EXISTS
-			(
-				SELECT
-					id
-				FROM products
-				WHERE id = oi.product_id
-			)
-		");
-	} else if ($CFG->dbms == "mysql") {
-	$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
-		WHERE	order_id = '$id'
-		");
-	}
+	$qid_items = new DB_Sql;
+	get_order_items(&$qid_items, $id);
 
-	$order = db_fetch_object($qid_order, 0);
+//	$order = db_fetch_object($qid_order, 0);
 
-	$qid_user = db_query("
-	SELECT usertype, fiscalcode, email
-	FROM users
-	WHERE username = '$order->username'
+	$qid_user= new DB_Sql;
+//	$qid_user = db_query("
+	$order_username = $qid_order->f("username");
+	$qid_user->Query("
+		SELECT usertype, fiscalcode, email
+		FROM users
+		WHERE username = '$order_username'
 	");
-	$user = db_fetch_object($qid_user, 0);
+	$qid_user->next_record();
+//	$user = db_fetch_object($qid_user, 0);
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_details.ihtml"));
@@ -137,22 +100,22 @@ function show_order_details($id) {
 	$t->set_var(array(
 			"order_id"		=> ov($id),
 			"page_number"		=> $page_number,
-			"order_state_name"	=> $order->state_name,
-			"order_date"		=> ov($order->date),
-			"order_username"	=> $order->username,
-			"order_amount"		=> $order->amount,
-			"order_famount"		=> formatted_price($order->amount),
-			"order_custinfo"	=> nl2br(ov($order->custinfo)),
-			"user_fiscalcode"	=> $user->fiscalcode,
-			"user_email"		=> $user->email,
-			"order_notes"		=> nl2br(ov($order->notes)),
-			"order_ournotes"	=> nl2br(ov($order->ournotes))
+			"order_state_name"	=> $qid_order->f("state_name"),
+			"order_date"		=> ov($qid_order->f("date")),
+			"order_username"	=> $qid_order->f("username"),
+			"order_amount"		=> $qid_order->f("amount"),
+			"order_famount"		=> formatted_price($qid_order->f("amount")),
+			"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
+			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+			"user_email"		=> $qid_user->f("email"),
+			"order_notes"		=> nl2br(ov($qid_order->f("notes"))),
+			"order_ournotes"	=> nl2br(ov($qid_order->f("ournotes")))
 	));
 	$t->set_block("page", "usertype_pf", "usertype_pf_blck");
 	$t->set_var("usertype_pf_blck", "");
 	$t->set_block("page", "usertype_az", "usertype_az_blck");
 	$t->set_var("usertype_az_blck", "");
-	if ($user->usertype == "pf")
+	if ($qid_user->f("usertype") == "pf")
 		$t->parse("usertype_pf_blck", "usertype_pf", true);
 	else
 		$t->parse("usertype_az_blck", "usertype_az", true);
@@ -168,31 +131,32 @@ function show_order_details($id) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_tr", "weight_used_tr_blck");
 		$t->set_block("item_row", "iva_used_tr", "iva_used_tr_blck");
-	$numr = db_num_rows($qid_items);
-	for ($i=0; $i<$numr; $i++) {
+//	$numr = db_num_rows($qid_items);
+//	for ($i=0; $i<$numr; $i++) {
+	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_tr_blck", "");
 		$t->set_var("iva_used_tr_blck", "");
-		$prod = db_fetch_object($qid_items, $i);
+//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($prod->product_id),
-				"prod_name"		=> ov($prod->name),
-				"prod_curr_price"	=> $prod->curr_price,
-				"prod_curr_fprice"	=> formatted_price($prod->curr_price),
-				"prod_purchase_price"	=> $prod->purchase_price,
-				"prod_purchase_fprice"	=> formatted_price($prod->purchase_price),
-				"prod_qty"		=> $prod->qty,
-				"prod_total"		=> $prod->total,
-				"prod_ftotal"		=> formatted_price($prod->total)
+				"prod_product_id"	=> ov($qid_items->f("product_id")),
+				"prod_name"		=> ov($qid_items->f("name")),
+				"prod_curr_price"	=> $qid_items->f("curr_price"),
+				"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
+				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+				"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
+				"prod_qty"		=> $qid_items->f("qty"),
+				"prod_total"		=> $qid_items->f("total"),
+				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
 		if($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $prod->purchase_weight,
-					"prod_purchase_fweight"	=> formatted_weight($prod->purchase_weight)
+					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+					"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_tr_blck", "weight_used_tr", true);
 		}
 		if ($SESSION["iva_used"]) {
-			$t->set_var("prod_purchase_iva", $prod->purchase_iva);
+			$t->set_var("prod_purchase_iva", $qid_items->f("purchase_iva"));
 			$t->parse("iva_used_tr_blck", "iva_used_tr", true);
 		}
 		$t->parse("item_rows", "item_row", true);
@@ -201,8 +165,8 @@ function show_order_details($id) {
 	$t->set_var("delivery_used_blck", "");
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $order->delivery,
-				"order_fdelivery"	=> formatted_price($order->delivery)
+				"order_delivery"	=> $qid_order->f("delivery"),
+				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
@@ -219,75 +183,52 @@ function print_edit_order_form($id) {
 	global $page_number;
 //	include ($CFG->globalerror);
 
-	$qid_order = db_query("SELECT * FROM orderscc WHERE id = '$id'");
-	$frm = db_fetch_array($qid_order, 0);
-	$qid_orders_states = db_query("SELECT * FROM orders_states ORDER BY name");
+	$qid_order = new DB_Sql;
+//	$qid_order = db_query("
+	$qid_order->Query("SELECT * FROM orderscc WHERE id = '$id'");
+	$qid_order->next_record();
+//	$frm = db_fetch_array($qid_order, 0);
+	$frm["id"] = $qid_order->f("id");
+	$frm["username"] = $qid_order->f("username");
+	$frm["date"] = $qid_order->f("date");
+	$frm["fromip"] = $qid_order->f("fromip");
+	$frm["custinfo"] = $qid_order->f("custinfo");
+	$frm["notes"] = $qid_order->f("notes");
+	$frm["ournotes"] = $qid_order->f("ournotes");
+	$frm["amount"] = $qid_order->f("amount");
+	$frm["delivery"] = $qid_order->f("delivery");
+	$frm["state_id"] = $qid_order->f("state_id");
+	$qid_orders_states = new DB_Sql;
+//	$qid_orders_states = db_query("
+	$qid_orders_states->Query("SELECT * FROM orders_states ORDER BY name");
 	$frm["order_state"] = array();
-	$numr = db_num_rows($qid_orders_states);
+//	$numr = db_num_rows($qid_orders_states);
+	$numr = $qid_orders_states->num_rows();
 	$frm["num_orders_states"] = $numr;
 	for ($i=0; $i<$numr; $i++) {
-		$order_state = db_fetch_object($qid_orders_states, $i);
-		$frm["order_state"][$i]["id"] = $order_state->id;
-		$frm["order_state"][$i]["name"] = $order_state->name;
+//		$order_state = db_fetch_object($qid_orders_states, $i);
+//		$frm["order_state"][$i]["id"] = $order_state->id;
+//		$frm["order_state"][$i]["name"] = $order_state->name;
+		$qid_orders_states->seek($i);
+		$qid_orders_states->next_record();
+		$frm["order_state"][$i]["id"] = $qid_orders_states->f("id");
+		$frm["order_state"][$i]["name"] = $qid_orders_states->f("name");
 	}
 
-	if ($CFG->dbms == "pgsql") {
-		$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi, products p
-		WHERE	oi.product_id = p.id AND order_id = '$id'
-		UNION
-		SELECT
-			 oi.product_id
-			,'-' as name
-			,0 as curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM order_items oi
-		WHERE order_id = '$id' AND
-			NOT EXISTS
-			(
-				SELECT
-					id
-				FROM products
-				WHERE id = oi.product_id
-			)
-		");
-	} else if ($CFG->dbms == "mysql") {
-	$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
-		WHERE	order_id = '$id'
-		");
-	}
+	$qid_items = new DB_Sql;
+	get_order_items(&$qid_items, $id);
 
-	$qid_user = db_query("
-	SELECT usertype, fiscalcode, email
-	FROM users
-	WHERE username = '$frm[username]'
+	$qid_user = new DB_Sql;
+//	$qid_user = db_query("
+	$qid_user->Query("
+		SELECT usertype, fiscalcode, email
+		FROM users
+		WHERE username = '$frm[username]'
 	");
+	$qid_user->next_record();
 
-	$order = db_fetch_object($qid_order, 0);
-	$user = db_fetch_object($qid_user, 0);
+//	$order = db_fetch_object($qid_order, 0);
+//	$user = db_fetch_object($qid_user, 0);
 
 	$frm["newmode"] = "update";
 	$frm["submit_caption"] = "Save_Changes";
@@ -305,9 +246,9 @@ function print_edit_order_form($id) {
 			"frm_username"		=> ov($frm["username"]),
 			"frm_amount"		=> $frm["amount"],
 			"frm_famount"		=> formatted_price($frm["amount"]),
-			"order_custinfo"	=> $order->custinfo,
-			"user_fiscalcode"	=> $user->fiscalcode,
-			"user_email"		=> $user->email,
+			"order_custinfo"	=> $qid_order->f("custinfo"),
+			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+			"user_email"		=> $qid_user->f("email"),
 			"order_notes"		=> $frm["notes"],
 			"order_ournotes"	=> $frm["ournotes"],
 			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
@@ -326,7 +267,7 @@ function print_edit_order_form($id) {
 	$t->set_var("usertype_pf_blck", "");
 	$t->set_block("page", "usertype_az", "usertype_az_blck");
 	$t->set_var("usertype_az_blck", "");
-	if ($user->usertype == "pf")
+	if ($qid_user->f("usertype") == "pf")
 		$t->parse("usertype_pf_blck", "usertype_pf", true);
 	else
 		$t->parse("usertype_az_blck", "usertype_az", true);
@@ -342,31 +283,32 @@ function print_edit_order_form($id) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_tr", "weight_used_tr_blck");
 		$t->set_block("item_row", "iva_used_tr", "iva_used_tr_blck");
-	$numr = db_num_rows($qid_items);
-	for ($i=0; $i<$numr; $i++) {
+//	$numr = db_num_rows($qid_items);
+//	for ($i=0; $i<$numr; $i++) {
+	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_tr_blck", "");
 		$t->set_var("iva_used_tr_blck", "");
-		$prod = db_fetch_object($qid_items, $i);
+//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($prod->product_id),
-				"prod_name"		=> ov($prod->name),
-				"prod_curr_price"	=> $prod->curr_price,
-				"prod_curr_fprice"	=> formatted_price($prod->curr_price),
-				"prod_purchase_price"	=> $prod->purchase_price,
-				"prod_purchase_fprice"	=> formatted_price($prod->purchase_price),
-				"prod_qty"		=> $prod->qty,
-				"prod_total"		=> $prod->total,
-				"prod_ftotal"		=> formatted_price($prod->total)
+				"prod_product_id"	=> ov($qid_items->f("product_id")),
+				"prod_name"		=> ov($qid_items->f("name")),
+				"prod_curr_price"	=> $qid_items->f("curr_price"),
+				"prod_curr_fprice"	=> formatted_price($qid_items->f("curr_price")),
+				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+				"prod_purchase_fprice"	=> formatted_price($qid_items->f("purchase_price")),
+				"prod_qty"		=> $qid_items->f("qty"),
+				"prod_total"		=> $qid_items->f("total"),
+				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
 		if($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $prod->purchase_weight,
-					"prod_purchase_fweight"	=> formatted_weight($prod->purchase_weight)
+					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+					"prod_purchase_fweight"	=> formatted_weight($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_tr_blck", "weight_used_tr", true);
 		}
 		if ($SESSION["iva_used"]) {
-			$t->set_var("prod_purchase_iva", $prod->purchase_iva);
+			$t->set_var("prod_purchase_iva", $qid_items->f("purchase_iva"));
 			$t->parse("iva_used_tr_blck", "iva_used_tr", true);
 		}
 		$t->parse("item_rows", "item_row", true);
@@ -375,8 +317,8 @@ function print_edit_order_form($id) {
 	$t->set_var("delivery_used_blck", "");
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $order->delivery,
-				"order_fdelivery"	=> formatted_price($order->delivery)
+				"order_delivery"	=> $qid_order->f("delivery"),
+				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
@@ -391,15 +333,28 @@ function delete_order($id) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_begin();
-	$qid = db_query("DELETE FROM orderscc WHERE id = '$id'");
-	$qid = db_query("DELETE FROM order_items WHERE order_id = '$id'");
-	$qid = db_commit();
+//	$qid = db_begin();
+//	$qid = db_query("DELETE FROM orderscc WHERE id = '$id'");
+//	$qid = db_query("DELETE FROM order_items WHERE order_id = '$id'");
+//	$qid = db_commit();
+	$qid = new DB_Sql;
+	$qid->begin();
+	$qid->Query("DELETE FROM orderscc WHERE id = '$id'");
+	$qid->Query("DELETE FROM order_items WHERE order_id = '$id'");
+	$qid->commit();
+
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_deleted.ihtml"));
 	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
-	$t->set_var("order_id", ov($id));
+	$t->set_var(array(
+			"order_id"	=> ov($id),
+			"backurl"	=> $backurl
+	));
 	$t->pparse("out", "page");
 //	include("templates/order_deleted.ihtml");
 }
@@ -407,14 +362,32 @@ function delete_order($id) {
 function update_order($frm) {
 // update the order record in the database
 
-	$qid = db_query("
-	UPDATE orderscc SET
-		 custinfo = '$frm[custinfo]'
-		,notes = '$frm[notes]'
-		,ournotes = '$frm[ournotes]'
-		,state_id = '$frm[state_id]'
-	WHERE id = '$frm[id]'
+	global $CFG, $SESSION;
+
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE orderscc SET
+			 custinfo = '$frm[custinfo]'
+			,notes = '$frm[notes]'
+			,ournotes = '$frm[ournotes]'
+			,state_id = '$frm[state_id]'
+		WHERE id = '$frm[id]'
 	");
+
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/order_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"order_id"	=> ov($frm["id"]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
 }
 
 function print_order_list() {
@@ -428,16 +401,28 @@ function print_order_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
-		FROM orderscc o, orders_states os
-		WHERE o.state_id = os.id
-		ORDER BY os.name, o.id ASC
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
+			FROM orderscc o, orders_states os
+			WHERE o.state_id = os.id
+			ORDER BY os.name, o.id ASC
   		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["orderscc"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["orderscc"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["orderscc"][$i]["id"] = $qid->f("id");
+			$SESSION["orderscc"][$i]["username"] = $qid->f("username");
+			$SESSION["orderscc"][$i]["date"] = $qid->f("date");
+			$SESSION["orderscc"][$i]["custinfo"] = $qid->f("custinfo");
+			$SESSION["orderscc"][$i]["amount"] = $qid->f("amount");
+			$SESSION["orderscc"][$i]["notes"] = $qid->f("notes");
+			$SESSION["orderscc"][$i]["state_name"] = $qid->f("state_name");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -472,7 +457,7 @@ function print_order_list() {
 		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
 	}
 	$t->set_block("page", "order_row", "order_rows");
-	$t->set_var("brand_rows", "");
+	$t->set_var("order_rows", "");
 	for ($i=$first; $i<=$last; $i++) {
 		$t->set_var(array(
 				"page_number"			=> $page_number,
