@@ -62,29 +62,42 @@ switch (nvl($mode)) {
 			$frm["product_id"] = $HTTP_POST_VARS["product_id"];
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["price"] = $HTTP_POST_VARS["price"];
+			$qid = new DB_Sql;
 			if ($SESSION["brand_used"]) {
 				// load up all the brands
-				$qid = db_query("SELECT id, name FROM brands");
+//				$qid = db_query("SELECT id, name FROM brands");
+				$qid->Query("SELECT id, name FROM brands");
 				$frm["brands"] = array();
-				$numr = db_num_rows($qid);
+//				$numr = db_num_rows($qid);
+				$numr = $qid->num_rows();
 				$frm["numbrands"] = $numr;
 				for ($i=0; $i<$numr; $i++) {
-					$brand = db_fetch_object($qid, $i);
-					$frm["brand"][$i]["id"] = $brand->id;
-					$frm["brand"][$i]["name"] = $brand->name;
+//					$brand = db_fetch_object($qid, $i);
+//					$frm["brand"][$i]["id"] = $brand->id;
+//					$frm["brand"][$i]["name"] = $brand->name;
+					$qid->seek($i);
+					$qid->next_record();
+					$frm["brand"][$i]["id"] = $qid->f("id");
+					$frm["brand"][$i]["name"] = $qid->f("name");
 				}
 				$frm["brand_id"] = $HTTP_POST_VARS["brand_id"];
 			}
 			if ($SESSION["iva_used"]) {
 				// load up all the iva percentages
-				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+//				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+				$qid->Query("SELECT id, iva FROM iva ORDER BY iva");
 				$frm["iva"] = array();
-				$numr = db_num_rows($qid);
+//				$numr = db_num_rows($qid);
+				$numr = $qid->num_rows();
 				$frm["numivavalues"] = $numr;
 				for ($i=0; $i<$numr; $i++) {
-					$iva = db_fetch_object($qid, $i);
-					$frm["iva"][$i]["id"] = $iva->id;
-					$frm["iva"][$i]["iva"] = $iva->iva;
+//					$iva = db_fetch_object($qid, $i);
+//					$frm["iva"][$i]["id"] = $iva->id;
+//					$frm["iva"][$i]["iva"] = $iva->iva;
+					$qid->seek($i);
+					$qid->next_record();
+					$frm["iva"][$i]["id"] = $qid->f("id");
+					$frm["iva"][$i]["iva"] = $qid->f("iva");
 				}
 				$frm["iva_id"] = $HTTP_POST_VARS["iva_id"];
 			}
@@ -128,29 +141,42 @@ switch (nvl($mode)) {
 			$frm["product_id"] = $HTTP_POST_VARS["product_id"];
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["price"] = $HTTP_POST_VARS["price"];
+			$qid = new DB_Sql;
 			if ($SESSION["brand_used"]) {
 				// load up all the brands
-				$qid = db_query("SELECT id, name FROM brands");
+//				$qid = db_query("SELECT id, name FROM brands");
+				$qid->Query("SELECT id, name FROM brands");
 				$frm["brands"] = array();
-				$numr = db_num_rows($qid);
+//				$numr = db_num_rows($qid);
+				$numr = $qid->num_rows();
 				$frm["numbrands"] = $numr;
 				for ($i=0; $i<$numr; $i++) {
-					$brand = db_fetch_object($qid, $i);
-					$frm["brand"][$i]["id"] = $brand->id;
-					$frm["brand"][$i]["name"] = $brand->name;
+//					$brand = db_fetch_object($qid, $i);
+//					$frm["brand"][$i]["id"] = $brand->id;
+//					$frm["brand"][$i]["name"] = $brand->name;
+					$qid->seek($i);
+					$qid->next_record();
+					$frm["brand"][$i]["id"] = $qid->f("id");
+					$frm["brand"][$i]["name"] = $qid->f("name");
 				}
 				$frm["brand_id"] = $HTTP_POST_VARS["brand_id"];
 			}
 			if ($SESSION["iva_used"]) {
 				// load up all the iva percentages
-				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+//				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+				$qid->Query("SELECT id, iva FROM iva ORDER BY iva");
 				$frm["iva"] = array();
-				$numr = db_num_rows($qid);
+//				$numr = db_num_rows($qid);
+				$numr = $qid->num_rows();
 				$frm["numivavalues"] = $numr;
 				for ($i=0; $i<$numr; $i++) {
-					$iva = db_fetch_object($qid, $i);
-					$frm["iva"][$i]["id"] = $iva->id;
-					$frm["iva"][$i]["iva"] = $iva->iva;
+//					$iva = db_fetch_object($qid, $i);
+//					$frm["iva"][$i]["id"] = $iva->id;
+//					$frm["iva"][$i]["iva"] = $iva->iva;
+					$qid->seek($i);
+					$qid->next_record();
+					$frm["iva"][$i]["id"] = $qid->f("id");
+					$frm["iva"][$i]["iva"] = $qid->f("iva");
 				}
 				$frm["iva_id"] = $HTTP_POST_VARS["iva_id"];
 			}
@@ -323,29 +349,43 @@ function print_add_product_form($category_id = 1) {
 	$frm["extended_description"] = "";
 	$frm["submit_caption"] = "Add_Product";
 
+	$qid = new DB_Sql;
+
 	if ($SESSION["brand_used"]) {
 		// load up all the brands
-		$qid = db_query("SELECT id, name FROM brands");
+//		$qid = db_query("SELECT id, name FROM brands");
+		$qid->Query("SELECT id, name FROM brands");
 		$frm["brands"] = array();
-		$numr = db_num_rows($qid);
+//		$numr = db_num_rows($qid);
+		$numr = $qid->num_rows();
 		$frm["numbrands"] = $numr;
 		for ($i=0; $i<$numr; $i++) {
-			$brand = db_fetch_object($qid, $i);
-			$frm["brand"][$i]["id"] = $brand->id;
-			$frm["brand"][$i]["name"] = $brand->name;
+//			$brand = db_fetch_object($qid, $i);
+//			$frm["brand"][$i]["id"] = $brand->id;
+//			$frm["brand"][$i]["name"] = $brand->name;
+			$qid->seek($i);
+			$qid->next_record();
+			$frm["brand"][$i]["id"] = $qid->f("id");
+			$frm["brand"][$i]["name"] = $qid->f("name");
 		}
 	}
 
 	if ($SESSION["iva_used"]) {
 		// load up all the iva percentages
-		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+//		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+		$qid->Query("SELECT id, iva FROM iva ORDER BY iva");
 		$frm["iva"] = array();
-		$numr = db_num_rows($qid);
+//		$numr = db_num_rows($qid);
+		$numr = $qid->num_rows();
 		$frm["numivavalues"] = $numr;
 		for ($i=0; $i<$numr; $i++) {
-			$iva = db_fetch_object($qid, $i);
-			$frm["iva"][$i]["id"] = $iva->id;
-			$frm["iva"][$i]["iva"] = $iva->iva;
+//			$iva = db_fetch_object($qid, $i);
+//			$frm["iva"][$i]["id"] = $iva->id;
+//			$frm["iva"][$i]["iva"] = $iva->iva;
+			$qid->seek($i);
+			$qid->next_record();
+			$frm["iva"][$i]["id"] = $qid->f("id");
+			$frm["iva"][$i]["iva"] = $qid->f("iva");
 		}
 	}
 
@@ -363,8 +403,28 @@ function print_edit_product_form($product_id) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the product */
-	$qid = db_query("SELECT * FROM products WHERE id = '$product_id'");
-	$frm = db_fetch_array($qid, 0);
+	$qid = new DB_Sql;
+//	$qid = db_query("SELECT * FROM products WHERE id = '$product_id'");
+	$qid->Query("SELECT * FROM products WHERE id = '$product_id'");
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["id"] = $qid->f("id");
+	$frm["name"] = $qid->f("name");
+	$frm["brand_id"] = $qid->f("brand_id");
+	$frm["price"] = $qid->f("price");
+	$frm["iva_id"] = $qid->f("iva_id");
+	$frm["discount"] = $qid->f("discount");
+	$frm["discqty"] = $qid->f("discqty");
+	$frm["weight"] = $qid->f("weight");
+	$frm["special_flag"] = $qid->f("special_flag");
+	$frm["special_level"] = $qid->f("special_level");
+	$frm["description"] = $qid->f("description");
+	$frm["extended_description"] = $qid->f("extended_description");
+	$frm["imagetype"] = $qid->f("imagetype");
+	$frm["imagewidth"] = $qid->f("imagewidth");
+	$frm["imageheight"] = $qid->f("imageheight");
+	$frm["thumbwidth"] = $qid->f("thumbwidth");
+	$frm["thumbheight"] = $qid->f("thumbheight");
 	$frm["old_product_id"] = $product_id;
 	$frm["old_imagetype"] = $frm["imagetype"];
 	$frm["old_imagewidth"] = $frm["imagewidth"];
@@ -375,42 +435,59 @@ function print_edit_product_form($product_id) {
 
 	if($SESSION["brand_used"]) {
 		// load up all the brands
-		$qid = db_query("SELECT id, name FROM brands");
+//		$qid = db_query("SELECT id, name FROM brands");
+		$qid->Query("SELECT id, name FROM brands");
 		$frm["brands"] = array();
-		$numr = db_num_rows($qid);
+//		$numr = db_num_rows($qid);
+		$numr = $qid->num_rows();
 		$frm["numbrands"] = $numr;
 		for ($i=0; $i<$numr; $i++) {
-			$brand = db_fetch_object($qid, $i);
-			$frm["brand"][$i]["id"] = $brand->id;
-			$frm["brand"][$i]["name"] = $brand->name;
+//			$brand = db_fetch_object($qid, $i);
+//			$frm["brand"][$i]["id"] = $brand->id;
+//			$frm["brand"][$i]["name"] = $brand->name;
+			$qid->seek($i);
+			$qid->next_record();
+			$frm["brand"][$i]["id"] = $qid->f("id");
+			$frm["brand"][$i]["name"] = $qid->f("name");
 		}
 	}
 
 	if ($SESSION["iva_used"]) {
 		// load up all the iva percentages
-		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+//		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
+		$qid->Query("SELECT id, iva FROM iva ORDER BY iva");
 		$frm["iva"] = array();
-		$numr = db_num_rows($qid);
+//		$numr = db_num_rows($qid);
+		$numr = $qid->num_rows();
 		$frm["numivavalues"] = $numr;
 		for ($i=0; $i<$numr; $i++) {
-			$iva = db_fetch_object($qid, $i);
-			$frm["iva"][$i]["id"] = $iva->id;
-			$frm["iva"][$i]["iva"] = $iva->iva;
+//			$iva = db_fetch_object($qid, $i);
+//			$frm["iva"][$i]["id"] = $iva->id;
+//			$frm["iva"][$i]["iva"] = $iva->iva;
+			$qid->seek($i);
+			$qid->next_record();
+			$frm["iva"][$i]["id"] = $qid->f("id");
+			$frm["iva"][$i]["iva"] = $qid->f("iva");
 		}
 	}
 
 	/* load up the categories for the product */
-	$qid = db_query("
-	SELECT category_id
-	FROM products_categories
-	WHERE product_id = '$product_id'
+//	$qid = db_query("
+	$qid->Query("
+		SELECT category_id
+		FROM products_categories
+		WHERE product_id = '$product_id'
 	");
 
 	$frm["categories"] = array();
-	$numr = db_num_rows($qid);
+//	$numr = db_num_rows($qid);
+	$numr = $qid->num_rows();
 	for ($i=0; $i<$numr; $i++) {
-		$cat = db_fetch_object($qid, $i);
-		$frm["categories"][] = $cat->category_id;
+//		$cat = db_fetch_object($qid, $i);
+		$qid->seek($i);
+		$qid->next_record();
+//		$frm["categories"][] = $cat->category_id;
+		$frm["categories"][] = $qid->f("category_id");
 	}
 
 	/* set values for the form */
@@ -431,25 +508,52 @@ function print_details_product($product_id) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the product */
-	$qid = db_query("
-	SELECT p.*, b.name AS bname, i.iva
-	FROM products p, brands b, iva i
-	WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT p.*, b.name AS bname, i.iva
+		FROM products p, brands b, iva i
+		WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
 	");
-	$frm = db_fetch_array($qid, 0);
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["id"] = $qid->f("id");
+	$frm["name"] = $qid->f("name");
+	$frm["brand_id"] = $qid->f("brand_id");
+	$frm["price"] = $qid->f("price");
+	$frm["iva_id"] = $qid->f("iva_id");
+	$frm["discount"] = $qid->f("discount");
+	$frm["discqty"] = $qid->f("discqty");
+	$frm["weight"] = $qid->f("weight");
+	$frm["special_flag"] = $qid->f("special_flag");
+	$frm["special_level"] = $qid->f("special_level");
+	$frm["description"] = $qid->f("description");
+	$frm["extended_description"] = $qid->f("extended_description");
+	$frm["imagetype"] = $qid->f("imagetype");
+	$frm["imagewidth"] = $qid->f("imagewidth");
+	$frm["imageheight"] = $qid->f("imageheight");
+	$frm["thumbwidth"] = $qid->f("thumbwidth");
+	$frm["thumbheight"] = $qid->f("thumbheight");
+	$frm["bname"] = $qid->f("bname");
+	$frm["iva"] = $qid->f("iva");
 
 	/* load up the categories for the product */
-	$qid = db_query("
-	SELECT category_id
-	FROM products_categories
-	WHERE product_id = '$product_id'
+//	$qid = db_query("
+	$qid->Query("
+		SELECT category_id
+		FROM products_categories
+		WHERE product_id = '$product_id'
 	");
 
 	$frm["categories"] = array();
-	$numr = db_num_rows($qid);
+//	$numr = db_num_rows($qid);
+	$numr = $qid->num_rows();
 	for ($i=0; $i<$numr; $i++) {
-		$cat = db_fetch_object($qid, $i);
-		$frm["categories"][] = $cat->category_id;
+//		$cat = db_fetch_object($qid, $i);
+		$qid->seek($i);
+		$qid->next_record();
+//		$frm["categories"][] = $cat->category_id;
+		$frm["categories"][] = $qid->f("category_id");
 	}
 
 	/* build the categories listbox options, preselect the selected item */
@@ -534,21 +638,25 @@ function delete_product($product_id) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	/* load up the information for the product */
-	$qid = db_query("
-	SELECT name, imagetype
-	FROM products
-	WHERE id = '$product_id'
+//	$qid = db_query("
+	$qid->Query("
+		SELECT name, imagetype
+		FROM products
+		WHERE id = '$product_id'
 	");
-	$prod = db_fetch_object($qid, 0);
+//	$prod = db_fetch_object($qid, 0);
+	$qid->next_record();
+	$prod->name = $qid->f("name");
+	$prod->imagetype = $qid->f("imagetype");
 
 	/* delete this product */
-	$qid = db_query("
-	DELETE FROM products
-	WHERE id = '$product_id'
-	");
+//	$qid = db_query("
+	$qid->Query("DELETE FROM products WHERE id = '$product_id'");
 
 // Remove the product image
 	if ($prod->imagetype != "") {
@@ -560,12 +668,14 @@ function delete_product($product_id) {
 	}
 
 	/* delete this product from the products_categories table */
-	$qid = db_query("
-	DELETE FROM products_categories
-	WHERE product_id = '$product_id'
+//	$qid = db_query("
+	$qid->Query("
+		DELETE FROM products_categories
+		WHERE product_id = '$product_id'
 	");
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -630,7 +740,9 @@ function insert_product($frm, $HTTP_POST_FILES) {
 		}
 	}
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	/* add the product into the products table */
 	if ($frm[extended_description] == "")
@@ -638,56 +750,59 @@ function insert_product($frm, $HTTP_POST_FILES) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	INSERT INTO products (
-		id
-		,name
-		,brand_id
-		,price
-		,iva_id
-		,discount
-		,discqty
-		,weight
-		,special_flag
-		,special_level
-		,description
-		,extended_description
-		,imagetype
-		,imagewidth
-		,imageheight
-		,thumbwidth
-		,thumbheight
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO products (
+			id
+			,name
+			,brand_id
+			,price
+			,iva_id
+			,discount
+			,discqty
+			,weight
+			,special_flag
+			,special_level
+			,description
+			,extended_description
+			,imagetype
+			,imagewidth
+			,imageheight
+			,thumbwidth
+			,thumbheight
 		)
-	VALUES (
-		'$frm[product_id]'
-		,'$frm[name]'
-		,'$frm[brand_id]'
-		,'$frm[price]'
-		,'$frm[iva_id]'
-		,'$frm[discount]'
-		,'$frm[discqty]'
-		,'$frm[weight]'
-		,'$frm[special_flag]'
-		,'$frm[special_level]'
-		,'$frm[description]'
-		,'$frm[extended_description]'
-		,'$type'
-		,'$size[0]'
-		,'$size[1]'
-		,'$thumbsize[0]'
-		,'$thumbsize[1]'
+		VALUES (
+			'$frm[product_id]'
+			,'$frm[name]'
+			,'$frm[brand_id]'
+			,'$frm[price]'
+			,'$frm[iva_id]'
+			,'$frm[discount]'
+			,'$frm[discqty]'
+			,'$frm[weight]'
+			,'$frm[special_flag]'
+			,'$frm[special_level]'
+			,'$frm[description]'
+			,'$frm[extended_description]'
+			,'$type'
+			,'$size[0]'
+			,'$size[1]'
+			,'$thumbsize[0]'
+			,'$thumbsize[1]'
 		)
 	");
 
 	/* add this product under the specified categories */
 	for ($i = 0; $i < count($frm["categories"]); $i++) {
-		$qid = db_query("
-		INSERT INTO products_categories (category_id, product_id)
-		VALUES ('{$frm["categories"][$i]}', '$frm[product_id]')
+//		$qid = db_query("
+		$qid->Query("
+			INSERT INTO products_categories (category_id, product_id)
+			VALUES ('{$frm["categories"][$i]}', '$frm[product_id]')
 		");
 	}
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -808,7 +923,9 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 		}
 	}
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	/* update the products table with the new information */
 	if ($frm[extended_description] == "")
@@ -816,32 +933,34 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-	$qid = db_query("
-	UPDATE products SET
-	 	 id = '$frm[product_id]'
-		,name = '$frm[name]'
-		,brand_id = '$frm[brand_id]'
-		,price = '$frm[price]'
-		,iva_id = '$frm[iva_id]'
-		,discount = '$frm[discount]'
-		,discqty = '$frm[discqty]'
-		,weight = '$frm[weight]'
-		,special_flag = '$frm[special_flag]'
-		,special_level = '$frm[special_level]'
-		,description = '$frm[description]'
-		,extended_description = '$frm[extended_description]'
-		,imagetype = '$type'
-		,imagewidth = '$imagewidth'
-		,imageheight = '$imageheight'
-		,thumbwidth = '$thumbwidth'
-		,thumbheight = '$thumbheight'
-	WHERE id = '$frm[old_product_id]'
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE products SET
+			 id = '$frm[product_id]'
+			,name = '$frm[name]'
+			,brand_id = '$frm[brand_id]'
+			,price = '$frm[price]'
+			,iva_id = '$frm[iva_id]'
+			,discount = '$frm[discount]'
+			,discqty = '$frm[discqty]'
+			,weight = '$frm[weight]'
+			,special_flag = '$frm[special_flag]'
+			,special_level = '$frm[special_level]'
+			,description = '$frm[description]'
+			,extended_description = '$frm[extended_description]'
+			,imagetype = '$type'
+			,imagewidth = '$imagewidth'
+			,imageheight = '$imageheight'
+			,thumbwidth = '$thumbwidth'
+			,thumbheight = '$thumbheight'
+		WHERE id = '$frm[old_product_id]'
 	");
 
 	/* delete all the categories this product was associated with */
-	$qid = db_query("
-	DELETE FROM products_categories
-	WHERE product_id = '$frm[old_product_id]'
+//	$qid = db_query("
+	$qid->Query("
+		DELETE FROM products_categories
+		WHERE product_id = '$frm[old_product_id]'
 	");
 
 	/* add associations for all the categories this product belongs to, if
@@ -852,13 +971,15 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 	}
 
 	for ($i = 0; $i < count($frm["categories"]); $i++) {
-		$qid = db_query("
-		INSERT INTO products_categories (category_id, product_id)
-		VALUES ('{$frm["categories"][$i]}', '$frm[product_id]')
+//		$qid = db_query("
+		$qid->Query("
+			INSERT INTO products_categories (category_id, product_id)
+			VALUES ('{$frm["categories"][$i]}', '$frm[product_id]')
 		");
 	}
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
 		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
@@ -887,28 +1008,46 @@ function print_product_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT
-			p.id AS product_id
-			,p.name
-			,p.price
-			,p.discount
-			,p.discqty
-			,p.weight
-			,p.imagetype
-			,p.imagewidth
-			,p.imageheight
-			,p.thumbwidth
-			,p.thumbheight
-			,c.name AS category
-			,i.iva
-		FROM products p, products_categories pc, categories c, iva i
-		WHERE p.id = pc.product_id AND c.id = pc.category_id AND p.iva_id = i.id ORDER BY c.name
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT
+				p.id AS product_id
+				,p.name
+				,p.price
+				,p.discount
+				,p.discqty
+				,p.weight
+				,p.imagetype
+				,p.imagewidth
+				,p.imageheight
+				,p.thumbwidth
+				,p.thumbheight
+				,c.name AS category
+				,i.iva
+			FROM products p, products_categories pc, categories c, iva i
+			WHERE p.id = pc.product_id AND c.id = pc.category_id AND p.iva_id = i.id ORDER BY c.name
   		");
 	
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["products"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["products"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["products"][$i]["product_id"] = $qid->f("product_id");
+			$SESSION["products"][$i]["name"] = $qid->f("name");
+			$SESSION["products"][$i]["price"] = $qid->f("price");
+			$SESSION["products"][$i]["discount"] = $qid->f("discount");
+			$SESSION["products"][$i]["discqty"] = $qid->f("discqty");
+			$SESSION["products"][$i]["weight"] = $qid->f("weight");
+			$SESSION["products"][$i]["magetype"] = $qid->f("magetype");
+			$SESSION["products"][$i]["imagewidth"] = $qid->f("imagewidth");
+			$SESSION["products"][$i]["imageheight"] = $qid->f("imageheight");
+			$SESSION["products"][$i]["thumbwidth"] = $qid->f("thumbwidth");
+			$SESSION["products"][$i]["thumbheight"] = $qid->f("thumbheight");
+			$SESSION["products"][$i]["category"] = $qid->f("category");
+			$SESSION["products"][$i]["iva"] = $qid->f("iva");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -957,6 +1096,13 @@ function print_product_list() {
 		$t->set_var("adminprodnoimage_blck", "");
 		$t->set_var("iva_used_blck", "");
 		$t->set_var("weight_used_td_blck", "");
+		$t->set_var(array(
+				"session_product_id"		=> ov($SESSION["products"][$i]["product_id"]),
+				"session_products_name"		=> ov($SESSION["products"][$i]["name"]),
+				"session_products_category"	=> ov($SESSION["products"][$i]["category"]),
+				"session_products_price"	=> $SESSION["products"][$i]["price"],
+				"session_products_fprice"	=> formatted_price($SESSION["products"][$i]["price"])
+		));
 		if (file_exists($CFG->productsdir.string_cleanup($SESSION["products"][$i]["product_id"]).".thumb.jpg")) {
 			$t->set_var(array(
 					"imagefilename"	=> string_cleanup($SESSION["products"][$i]["product_id"]),
@@ -966,13 +1112,6 @@ function print_product_list() {
 			$t->parse("adminprodimage_blck", "adminprodimage", true);
 		} else
 			$t->parse("adminprodnoimage_blck", "adminprodnoimage", true);
-		$t->set_var(array(
-				"session_product_id"		=> ov($SESSION["products"][$i]["product_id"]),
-				"session_products_name"		=> ov($SESSION["products"][$i]["name"]),
-				"session_products_category"	=> ov($SESSION["products"][$i]["category"]),
-				"session_products_price"	=> $SESSION["products"][$i]["price"],
-				"session_products_fprice"	=> formatted_price($SESSION["products"][$i]["price"])
-		));
 		if ($SESSION["iva_used"]) {
 			$t->set_var("session_products_iva", $SESSION["products"][$i]["iva"]);
 			$t->parse("iva_used_blck", "iva_used", true);
@@ -1015,10 +1154,12 @@ function print_import_products_form() {
 function import_products($HTTP_POST_FILES) {
 /* Import products from a text file */
 	global $CFG, $ME, $SESSION;
-//	include ($CFG->globalerror);
+	include ($CFG->globalerror);
 
 	/* Let's open a transaction */
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
@@ -1032,16 +1173,18 @@ function import_products($HTTP_POST_FILES) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the category exists ... */
-		$qid = db_query("
-		SELECT id, name FROM categories WHERE name = '$fldarr[0]'
-		");
-		if (db_num_rows($qid) == 0) {
+//		$qid = db_query("
+		$qid->Query("SELECT id FROM categories WHERE name = '$fldarr[0]'");
+//		if (db_num_rows($qid) == 0) {
+		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's return an error ... */
 			echo $line_num . $Err_ImpCat . $fldarr[0] . "'.<br>";
 		} else {
 			/* ... otherwise let's save its ID ... */
-			$arr = db_fetch_array($qid,0);
-			$pid = $arr[0];
+//			$arr = db_fetch_array($qid,0);
+//			$pid = $arr[0];
+			$qid->next_record();
+			$pid = $qid->f("id");
 
 			if($SESSION["brand_used"]) {
 				if ($fldarr[3] == "") {
@@ -1049,17 +1192,19 @@ function import_products($HTTP_POST_FILES) {
 					$fldarr[3] = 0;
 				} else {
 					/* Let's see if the brand exists ... */
-					$qid = db_query("
-					SELECT id FROM brands WHERE name = '$fldarr[3]'
-					");
-					if (db_num_rows($qid) == 0) {
+//					$qid = db_query("
+					$qid->Query("SELECT id FROM brands WHERE name = '$fldarr[3]'");
+//					if (db_num_rows($qid) == 0) {
+					if ($qid->num_rows() == 0) {
 						/* ... if it doesn't exist let's return an error ... */
 						echo $line_num . $Err_ImpBrand . $fldarr[3] . "'.<br>";
 						$fldarr[3] = "";
 					} else {
 						/* ... otherwise let's substitute it with its id */
-						$arr = db_fetch_array($qid, 0);
-						$fldarr[3] = $arr[0];
+//						$arr = db_fetch_array($qid, 0);
+//						$fldarr[3] = $arr[0];
+						$qid->next_record();
+						$fldarr[3] = $qid->f("id");
 					}
 				}
 			}
@@ -1069,93 +1214,103 @@ function import_products($HTTP_POST_FILES) {
 					$fldarr[5] = 0;
 				} else {
 					/* Let's see if the iva exists ... */
-					$qid = db_query("
-					SELECT id FROM iva WHERE iva = '$fldarr[5]'
-					");
-					if (db_num_rows($qid) == 0) {
+//					$qid = db_query("
+					$qid->Query("SELECT id FROM iva WHERE iva = '$fldarr[5]'");
+//					if (db_num_rows($qid) == 0) {
+					if ($qid->num_rows() == 0) {
 						/* ... if it doesn't exist let's return an error ... */
 						echo $line_num . $Err_ImpIVA . $fldarr[5] . "'.<br>";
 						$fldarr[5] = "";
 					} else {
 						/* ... otherwise let's substitute it with its id */
-						$arr = db_fetch_array($qid, 0);
-						$fldarr[5] = $arr[0];
+//						$arr = db_fetch_array($qid, 0);
+//						$fldarr[5] = $arr[0];
+						$qid->next_record();
+						$fldarr[5] = $qid->f("id");
 					}
 				}
 			}
 
 			/* ... and let's see if the product already exists ... */
-			$qid = db_query("
-			SELECT id, name FROM products WHERE id = '$fldarr[1]'
-			");
-			if (db_num_rows($qid) == 0) {
+//			$qid = db_query("
+			$qid->Query("SELECT id, name FROM products WHERE id = '$fldarr[1]'");
+//			if (db_num_rows($qid) == 0) {
+			if ($qid->num_rows() == 0) {
 				/* ... if it doesn't exist let's create it in the products table ... */
 				if ($frm[extended_description] == "")
 					$frm[extended_description] = $frm[description];
-				$qid = db_query("
-				INSERT INTO products (
-					id
-					,name
-					,brand_id
-					,price
-					,iva_id
-					,discount
-					,discqty
-					,weight
-					,special_flag
-					,special_level
-					,description
-					,extended_description
+//				$qid = db_query("
+				$qid->Query("
+					INSERT INTO products (
+						id
+						,name
+						,brand_id
+						,price
+						,iva_id
+						,discount
+						,discqty
+						,weight
+						,special_flag
+						,special_level
+						,description
+						,extended_description
 					)
-				VALUES (
-					'$fldarr[1]'
-					,'$fldarr[2]'
-					,'$fldarr[3]'
-					,'$fldarr[4]'
-					,'$fldarr[5]'
-					,'$fldarr[6]'
-					,'$fldarr[7]'
-					,'$fldarr[8]'
-					,'$fldarr[9]'
-					,'$fldarr[10]'
-					,'$fldarr[11]'
-					,'$fldarr[12]'
+					VALUES (
+						'$fldarr[1]'
+						,'$fldarr[2]'
+						,'$fldarr[3]'
+						,'$fldarr[4]'
+						,'$fldarr[5]'
+						,'$fldarr[6]'
+						,'$fldarr[7]'
+						,'$fldarr[8]'
+						,'$fldarr[9]'
+						,'$fldarr[10]'
+						,'$fldarr[11]'
+						,'$fldarr[12]'
 					)
 				");
 				/* ... and create it in the products_categories table ... */
-				$qid = db_query("
-				INSERT INTO products_categories (product_id, category_id)
-				VALUES ('$fldarr[1]', '$pid')
+//				$qid = db_query("
+				$qid->Query("
+					INSERT INTO products_categories (product_id, category_id)
+					VALUES ('$fldarr[1]', '$pid')
 				");
 			}
 			else {
 				/* ... otherwise let's update it in the products table ... */
 				if ($frm[extended_description] == "")
 					$frm[extended_description] = $frm[description];
-				$qid = db_query("
-				UPDATE products SET
-					name = '$fldarr[2]'
-		 			,brand_id = '$fldarr[3]'
-		 			,price = '$fldarr[4]'
-		 			,iva_id = '$fldarr[5]'
-					,discount = '$fldarr[6]'
-					,discqty = '$fldarr[7]'
-					,weight = '$fldarr[8]'
-					,special_flag = '$fldarr[9]'
-					,special_level = '$fldarr[10]'
-					,description = '$fldarr[11]'
-					,extended_description = '$fldarr[12]'
-				WHERE id = '$fldarr[1]'
+//				$qid = db_query("
+				$qid->Query("
+					UPDATE products SET
+						name = '$fldarr[2]'
+						,brand_id = '$fldarr[3]'
+						,price = '$fldarr[4]'
+						,iva_id = '$fldarr[5]'
+						,discount = '$fldarr[6]'
+						,discqty = '$fldarr[7]'
+						,weight = '$fldarr[8]'
+						,special_flag = '$fldarr[9]'
+						,special_level = '$fldarr[10]'
+						,description = '$fldarr[11]'
+						,extended_description = '$fldarr[12]'
+					WHERE id = '$fldarr[1]'
 				");
 				/* ... then, let's see if the product already exists with this category ... */
-				$qid = db_query("
-				SELECT category_id FROM products_categories WHERE product_id = '$fldarr[1]' AND category_id = '$pid'
+//				$qid = db_query("
+				$qid->Query("
+					SELECT category_id
+					FROM products_categories
+					WHERE product_id = '$fldarr[1]' AND category_id = '$pid'
 				");
-				if (db_num_rows($qid) == 0) {
+//				if (db_num_rows($qid) == 0) {
+				if ($qid->num_rows() == 0) {
 					/* ... if it doesn't exist let's create it in the products_categories table ... */
-					$qid = db_query("
-					INSERT INTO products_categories (product_id, category_id)
-					VALUES ('$fldarr[1]', '$pid')
+//					$qid = db_query("
+					$qid->Query("
+						INSERT INTO products_categories (product_id, category_id)
+						VALUES ('$fldarr[1]', '$pid')
 					");
 				}
 			}
@@ -1164,7 +1319,8 @@ function import_products($HTTP_POST_FILES) {
 	}
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
@@ -1207,11 +1363,13 @@ function print_import_images_form() {
 function import_images($HTTP_POST_FILES) {
 /* Import products from a text file */
 	global $CFG, $ME, $SESSION;
-//	include ($CFG->globalerror);
+	include ($CFG->globalerror);
 	$upload_path = $CFG->productsdir;
 
 	/* Let's open a transaction */
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	// Let's unzip the file with images into tempdir ...
 //	$tmpdir = get_cfg_var("upload_tmp_dir");
@@ -1264,21 +1422,29 @@ function import_images($HTTP_POST_FILES) {
 					$thumbsize = getimagesize ($upload_name_thumb);
 // if we are updating a product image and the old imagetype
 // is empty or different from the new one, then we remove the old image
-					$qid = db_query("SELECT imagetype FROM products WHERE id = '$appoggio'");
-					$arr = db_fetch_array($qid, 0);
-					$oldtype = $arr["imagetype"];
+//					$qid = db_query("
+					$qid->Query("
+						SELECT imagetype
+						FROM products
+						WHERE id = '$appoggio'
+					");
+//					$arr = db_fetch_array($qid, 0);
+					$qid->next_record();
+//					$oldtype = $arr["imagetype"];
+					$oldtype = $qid->f("imagetype");
 					if ($type != $oldtype) {
 						system ("rm -f ".$upload_name_old, $result);
 					}
 
-					$qid = db_query("
-					UPDATE products SET
-						 imagetype = '$type'
-						,imagewidth = '$size[0]'
-						,imageheight = '$size[1]'
-						,thumbwidth = '$thumbsize[0]'
-						,thumbheight = '$thumbsize[1]'
-					WHERE id = '$appoggio'
+//					$qid = db_query("
+					$qid->Query("
+						UPDATE products SET
+							 imagetype = '$type'
+							,imagewidth = '$size[0]'
+							,imageheight = '$size[1]'
+							,thumbwidth = '$thumbsize[0]'
+							,thumbheight = '$thumbsize[1]'
+						WHERE id = '$appoggio'
 					");
 				}
 			}
@@ -1290,7 +1456,8 @@ function import_images($HTTP_POST_FILES) {
 	system ("rm -rf $tmpdir", $result);
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
