@@ -43,7 +43,7 @@ switch (nvl($mode)) {
 
 	case "del" :
 		delete_user($username);
-		print_user_list();
+//		print_user_list();
 		break;
 
 	case "insert" :
@@ -84,7 +84,7 @@ switch (nvl($mode)) {
 */
 		if (empty($errormsg)) {
 			insert_user($HTTP_POST_VARS);
-			print_user_list();
+//			print_user_list();
 		} else {
 			$frm["username"] = $HTTP_POST_VARS["username"];
 			$frm["usertype"] = $HTTP_POST_VARS["usertype"];
@@ -146,7 +146,7 @@ switch (nvl($mode)) {
 */
 		if (empty($errormsg)) {
 			update_user($HTTP_POST_VARS);
-			print_user_list();
+//			print_user_list();
 		} else {
 			$frm["username"] = $HTTP_POST_VARS["username"];
 			$frm["usertype"] = $HTTP_POST_VARS["usertype"];
@@ -284,33 +284,36 @@ function show_user_details($username) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_query("SELECT * FROM users WHERE username = '$username'");
-	$frm = db_fetch_array($qid, 0);
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("SELECT * FROM users WHERE username = '$username'");
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
 
 	$t = new Template();
-	$t->set_file(array("page" => "templates/user_details-".$frm["usertype"].".ihtml"));
+	$t->set_file(array("page" => "templates/user_details-".$qid->f("usertype").".ihtml"));
 	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
 	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
 	$t->set_var(array(
-			"frm_username"		=> ov($frm[username]),
-			"frm_priv"		=> ov($frm[priv]),
-			"frm_firstname"		=> ov($frm[firstname]),
-			"frm_lastname"		=> ov($frm[lastname]),
-			"frm_fiscalcode"	=> ov($frm[fiscalcode]),
-			"frm_address"		=> ovwbr($frm[address]),
-			"frm_number"		=> ov($frm[number]),
-			"frm_city"		=> ov($frm[city]),
-			"frm_country"		=> ov($frm[country]),
-			"frm_zip_code"		=> ov($frm[zip_code]),
-			"frm_phone"		=> ov($frm[phone]),
-			"frm_fax"		=> ov($frm[fax]),
-			"frm_mobilephone"	=> ov($frm[mobilephone]),
-			"frm_email"		=> ov($frm[email]),
-			"frm_authdata"		=> $frm["authdata"] ? strtoupper($yes) : "" ,
+			"frm_username"		=> ov($qid->f("username")),
+			"frm_priv"		=> ov($qid->f("priv")),
+			"frm_firstname"		=> ov($qid->f("firstname")),
+			"frm_lastname"		=> ov($qid->f("lastname")),
+			"frm_fiscalcode"	=> ov($qid->f("fiscalcode")),
+			"frm_address"		=> ovwbr($qid->f("address")),
+			"frm_number"		=> ov($qid->f("number")),
+			"frm_city"		=> ov($qid->f("city")),
+			"frm_country"		=> ov($qid->f("country")),
+			"frm_zip_code"		=> ov($qid->f("zip_code")),
+			"frm_phone"		=> ov($qid->f("phone")),
+			"frm_fax"		=> ov($qid->f("fax")),
+			"frm_mobilephone"	=> ov($qid->f("mobilephone")),
+			"frm_email"		=> ov($qid->f("email")),
+			"frm_authdata"		=> $qid->f("authdata") ? strtoupper($yes) : "" ,
 			"frm_acceptadvert"	=> $frm["acceptadvert"] ? strtoupper($yes) : "" ,
-			"frm_notes"		=> ovwbr($frm[notes]),
-			"frm_ournotes"		=> ovwbr($frm[ournotes]),
-			"frm_date"		=> ov($frm[date]),
+			"frm_notes"		=> ovwbr($qid->f("notes")),
+			"frm_ournotes"		=> ovwbr($qid->f("ournotes")),
+			"frm_date"		=> ov($qid->f("date")),
 	));
 	$t->pparse("out", "page");
 //	include("templates/user_details-".$frm["usertype"].".ihtml");
@@ -356,10 +359,34 @@ function print_edit_user_form($username) {
 //	include ($CFG->globalerror);
 
 	/* load up the information for the user */
-	$qid = db_query("
-	SELECT * FROM users WHERE username = '$username'
-	");
-	$frm = db_fetch_array($qid, 0);
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("SELECT * FROM users WHERE username = '$username'");
+//	$frm = db_fetch_array($qid, 0);
+	$qid->next_record();
+	$frm["username"] = $qid->f("username");
+	$frm["password"] = $qid->f("password");
+	$frm["usertype"] = $qid->f("usertype");
+	$frm["priv"] = $qid->f("priv");
+	$frm["firstname"] = $qid->f("firstname");
+	$frm["lastname"] = $qid->f("lastname");
+	$frm["fiscalcode"] = $qid->f("fiscalcode");
+	$frm["address"] = $qid->f("address");
+	$frm["number"] = $qid->f("number");
+	$frm["city"] = $qid->f("city");
+	$frm["country"] = $qid->f("country");
+	$frm["zip_code"] = $qid->f("zip_code");
+	$frm["phone"] = $qid->f("phone");
+	$frm["fax"] = $qid->f("fax");
+	$frm["mobilephone"] = $qid->f("mobilephone");
+	$frm["email"] = $qid->f("email");
+	$frm["authdata"] = $qid->f("authdata");
+	$frm["acceptadvert"] = $qid->f("acceptadvert");
+	$frm["notes"] = $qid->f("notes");
+	$frm["ournotes"] = $qid->f("ournotes");
+	$frm["date"] = $qid->f("date");
+	$frm["fromip"] = $qid->f("fromip");
+
 	$frm["old_email"] = $frm["email"];
 
 	$frm["newmode"] = "update";
@@ -375,10 +402,19 @@ function delete_user($username) {
 	global $SESSION;
 //	include ($CFG->globalerror);
 
-	$qid = db_query("SELECT priv FROM users WHERE username = '$username'");
-	$user = db_fetch_object($qid, 0);
-	if ($user->priv != "admin") {
-		$qid = db_query("DELETE FROM users WHERE username = '$username'");
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("SELECT priv FROM users WHERE username = '$username'");
+//	$user = db_fetch_object($qid, 0);
+	$qid->next_record();
+	if ($qid->f("priv") != "admin") {
+//		$qid = db_query("
+		$qid->Query("DELETE FROM users WHERE username = '$username'");
+
+		if (empty($SESSION["goback"]["query_string"]))
+			$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		else
+			$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 
 		$t = new Template();
 		$t->set_file(array("page" => "templates/user_deleted.ihtml"));
@@ -386,6 +422,7 @@ function delete_user($username) {
 		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
 		$t->set_var(array(
 				"username"	=> ov($username),
+				"backurl"	=> $backurl
 		));
 		$t->pparse("out", "page");
 //		include("templates/user_deleted.ihtml");
@@ -408,55 +445,63 @@ function insert_user($frm) {
 
 	$password = generate_password();
 
-	$qid = db_query("
-	INSERT INTO users (
-		username
-		,password
-		,usertype
-		,priv
-		,firstname
-		,lastname
-		,fiscalcode
-		,address
-		,number
-		,city
-		,country
-		,zip_code
-		,phone
-		,fax
-		,mobilephone
-		,email
-		,authdata
-		,acceptadvert
-		,notes
-		,ournotes
-		,date
-		,fromip
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO users (
+			username
+			,password
+			,usertype
+			,priv
+			,firstname
+			,lastname
+			,fiscalcode
+			,address
+			,number
+			,city
+			,country
+			,zip_code
+			,phone
+			,fax
+			,mobilephone
+			,email
+			,authdata
+			,acceptadvert
+			,notes
+			,ournotes
+			,date
+			,fromip
 		)
-	VALUES (
-		 '$frm[username]'
-		,'" . md5($password) ."'
-		,'$frm[usertype]'
-		,'$frm[priv]'
-		,'$frm[firstname]'
-		,'$frm[lastname]'
-		,'$frm[fiscalcode]'
-		,'$frm[address]'
-		,'$frm[number]'
-		,'$frm[city]'
-		,'$frm[country]'
-		,'$frm[zip_code]'
-		,'$frm[phone]'
-		,'$frm[fax]'
-		,'$frm[mobilephone]'
-		,'$frm[email]'
-		,'$frm[authdata]'
-		,'$frm[acceptadvert]'
-		,'$frm[notes]'
-		,'$frm[ournotes]'
-		,'$date'
-		,'$fromip'
-	)");
+		VALUES (
+			 '$frm[username]'
+			,'" . md5($password) ."'
+			,'$frm[usertype]'
+			,'$frm[priv]'
+			,'$frm[firstname]'
+			,'$frm[lastname]'
+			,'$frm[fiscalcode]'
+			,'$frm[address]'
+			,'$frm[number]'
+			,'$frm[city]'
+			,'$frm[country]'
+			,'$frm[zip_code]'
+			,'$frm[phone]'
+			,'$frm[fax]'
+			,'$frm[mobilephone]'
+			,'$frm[email]'
+			,'$frm[authdata]'
+			,'$frm[acceptadvert]'
+			,'$frm[notes]'
+			,'$frm[ournotes]'
+			,'$date'
+			,'$fromip'
+		)
+	");
+
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_added.ihtml"));
@@ -464,6 +509,7 @@ function insert_user($frm) {
 	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
 	$t->set_var(array(
 			"frm_username"	=> ov($frm[username]),
+			"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
 //	include("templates/user_added.ihtml");
@@ -476,34 +522,42 @@ function update_user($frm) {
 	global $username;
 //	include ($CFG->globalerror);
 
-	$qid = db_query("
-	UPDATE users SET
-		 priv = '$frm[priv]'
-		,firstname = '$frm[firstname]'
-		,lastname = '$frm[lastname]'
-		,fiscalcode = '$frm[fiscalcode]'
-		,address = '$frm[address]'
-		,number = '$frm[number]'
-		,city = '$frm[city]'
-		,country = '$frm[country]'
-		,zip_code = '$frm[zip_code]'
-		,phone = '$frm[phone]'
-		,fax = '$frm[fax]'
-		,mobilephone = '$frm[mobilephone]'
-		,email = '$frm[email]'
-		,authdata = '$frm[authdata]'
-		,acceptadvert = '$frm[acceptadvert]'
-		,notes = '$frm[notes]'
-		,ournotes = '$frm[ournotes]'
-	WHERE username = '$frm[username]'
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE users SET
+			 priv = '$frm[priv]'
+			,firstname = '$frm[firstname]'
+			,lastname = '$frm[lastname]'
+			,fiscalcode = '$frm[fiscalcode]'
+			,address = '$frm[address]'
+			,number = '$frm[number]'
+			,city = '$frm[city]'
+			,country = '$frm[country]'
+			,zip_code = '$frm[zip_code]'
+			,phone = '$frm[phone]'
+			,fax = '$frm[fax]'
+			,mobilephone = '$frm[mobilephone]'
+			,email = '$frm[email]'
+			,authdata = '$frm[authdata]'
+			,acceptadvert = '$frm[acceptadvert]'
+			,notes = '$frm[notes]'
+			,ournotes = '$frm[ournotes]'
+		WHERE username = '$frm[username]'
 	");
 
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_updated.ihtml"));
 	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
 	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
 	$t->set_var(array(
 			"username"	=> ov($username),
+			"backurl"	=> $backurl
 	));
 	$t->pparse("out", "page");
 //	include("templates/user_updated.ihtml");
@@ -520,16 +574,28 @@ function print_user_list() {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT username, firstname, lastname, phone, email, authdata, acceptadvert
-		FROM users
-		WHERE username <> 'root'
-		ORDER BY username ASC
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT username, firstname, lastname, phone, email, authdata, acceptadvert
+			FROM users
+			WHERE username <> 'root'
+			ORDER BY username ASC
 		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["users"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["users"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["users"][$i]["username"] = $qid->f("username");
+			$SESSION["users"][$i]["firstname"] = $qid->f("firstname");
+			$SESSION["users"][$i]["lastname"] = $qid->f("lastname");
+			$SESSION["users"][$i]["phone"] = $qid->f("phone");
+			$SESSION["users"][$i]["email"] = $qid->f("email");
+			$SESSION["users"][$i]["authdata"] = $qid->f("authdata");
+			$SESSION["users"][$i]["acceptadvert"] = $qid->f("acceptadvert");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
@@ -610,7 +676,9 @@ function import_users($userfile) {
 //	include ($CFG->globalerror);
 
 	/* Let's open a transaction */
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
 	$fcontents = file ($userfile);
 	/* Traverse the file */
@@ -625,92 +693,95 @@ function import_users($userfile) {
 			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the user already exists ... */
-		$qid = db_query("
-		SELECT username FROM users WHERE username = '$fldarr[0]'
-		");
-		if (db_num_rows($qid) == 0) {
+//		$qid = db_query("
+		$qid->Query("SELECT username FROM users WHERE username = '$fldarr[0]'");
+//		if (db_num_rows($qid) == 0) {
+		if ($qid->num_rows() == 0) {
 			/* ... if it doesn't exist let's create it in the users table ... */
-			$qid = db_query("
-			INSERT INTO users (
-				username
-				,password
-				,usertype
-				,priv
-				,firstname
-				,lastname
-				,fiscalcode
-				,address
-				,number
-				,city
-				,country
-				,zip_code
-				,phone
-				,fax
-				,mobilephone
-				,email
-				,authdata
-				,acceptadvert
-				,notes
-				,ournotes
-				,date
-				,fromip
+//			$qid = db_query("
+			$qid->Query("
+				INSERT INTO users (
+					username
+					,password
+					,usertype
+					,priv
+					,firstname
+					,lastname
+					,fiscalcode
+					,address
+					,number
+					,city
+					,country
+					,zip_code
+					,phone
+					,fax
+					,mobilephone
+					,email
+					,authdata
+					,acceptadvert
+					,notes
+					,ournotes
+					,date
+					,fromip
 				)
-			VALUES (
-		 		'$fldarr[0]'
-				,'" . md5($fldarr[1]) ."'
-				,'$fldarr[2]'
-				,'$fldarr[3]'
-				,'$fldarr[4]'
-				,'$fldarr[5]'
-				,'$fldarr[6]'
-				,'$fldarr[7]'
-				,'$fldarr[8]'
-				,'$fldarr[9]'
-				,'$fldarr[10]'
-				,'$fldarr[11]'
-				,'$fldarr[12]'
-				,'$fldarr[13]'
-				,'$fldarr[14]'
-				,'$fldarr[15]'
-				,'$fldarr[16]'
-				,'$fldarr[17]'
-				,'$fldarr[18]'
-				,'$fldarr[19]'
-				,'$fldarr[20]'
-				,'$fldarr[21]'
-			)");
-		}
-		else {
+				VALUES (
+					'$fldarr[0]'
+					,'" . md5($fldarr[1]) ."'
+					,'$fldarr[2]'
+					,'$fldarr[3]'
+					,'$fldarr[4]'
+					,'$fldarr[5]'
+					,'$fldarr[6]'
+					,'$fldarr[7]'
+					,'$fldarr[8]'
+					,'$fldarr[9]'
+					,'$fldarr[10]'
+					,'$fldarr[11]'
+					,'$fldarr[12]'
+					,'$fldarr[13]'
+					,'$fldarr[14]'
+					,'$fldarr[15]'
+					,'$fldarr[16]'
+					,'$fldarr[17]'
+					,'$fldarr[18]'
+					,'$fldarr[19]'
+					,'$fldarr[20]'
+					,'$fldarr[21]'
+				)
+			");
+		} else {
 			/* ... otherwise let's update it in the products table ... */
-			$qid = db_query("
-			UPDATE users SET
-				usertype = '$fldarr[2]'
-				,priv = '$fldarr[3]'
-				,firstname = '$fldarr[4]'
-				,lastname = '$fldarr[5]'
-				,fiscalcode = '$fldarr[6]'
-				,address = '$fldarr[7]'
-				,number = '$fldarr[8]'
-				,city = '$fldarr[9]'
-				,country = '$fldarr[10]'
-				,zip_code = '$fldarr[11]'
-				,phone = '$fldarr[12]'
-				,fax = '$fldarr[13]'
-				,mobilephone = '$fldarr[14]'
-				,email = '$fldarr[15]'
-				,authdata = '$fldarr[16]'
-				,acceptadvert = '$fldarr[17]'
-				,notes = '$fldarr[18]'
-				,ournotes = '$fldarr[19]'
-				,date = '$fldarr[20]'
-				,fromip = '$fldarr[21]'
-			WHERE username = '$fldarr[0]'
+//			$qid = db_query("
+			$qid->Query("
+				UPDATE users SET
+					usertype = '$fldarr[2]'
+					,priv = '$fldarr[3]'
+					,firstname = '$fldarr[4]'
+					,lastname = '$fldarr[5]'
+					,fiscalcode = '$fldarr[6]'
+					,address = '$fldarr[7]'
+					,number = '$fldarr[8]'
+					,city = '$fldarr[9]'
+					,country = '$fldarr[10]'
+					,zip_code = '$fldarr[11]'
+					,phone = '$fldarr[12]'
+					,fax = '$fldarr[13]'
+					,mobilephone = '$fldarr[14]'
+					,email = '$fldarr[15]'
+					,authdata = '$fldarr[16]'
+					,acceptadvert = '$fldarr[17]'
+					,notes = '$fldarr[18]'
+					,ournotes = '$fldarr[19]'
+					,date = '$fldarr[20]'
+					,fromip = '$fldarr[21]'
+				WHERE username = '$fldarr[0]'
 			");
 		}
 	}
 
 	/* Let's close the transaction */
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
