@@ -23,25 +23,22 @@ class object {};
 /* setup the configuration object */
 $CFG = new object;
 
-$CFG->dbhost = "localhost";
-$CFG->port = "5432";
-$CFG->dbname = "pgmarket";
-$CFG->dbuser = "postgres";
-$CFG->dbpass = "postgres";
+$CFG->dbms = "pgsql";	// PostgreSQL
+//$CFG->dbms = "mysql";	// MySQL
 
-$CFG->myname = "PgMarket 1.4.4";
+$CFG->myname = "PgMarket 1.5.1 (development)";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
-$CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
-$CFG->templatedir = "$CFG->dirroot/templates/";	// with an ending "/"
-$CFG->libdir      = "$CFG->dirroot/lib";	// without an ending "/"
-$CFG->libwww      = "$CFG->wwwroot/lib";	// without an ending "/"
-$CFG->localedir   = "$CFG->dirroot/locale/";	// with an ending "/"
-$CFG->productswww = "$CFG->wwwroot/products/";	// with an ending "/"
-$CFG->productsdir = "$CFG->dirroot/products/";	// with an ending "/"
-$CFG->images      = "$CFG->wwwroot/images/";	// with an ending "/"
-$CFG->wordlist    = "$CFG->libdir/wordlist.txt";
+$CFG->firstpage   = $CFG->wwwroot . "/firstpage.php";
+$CFG->templatedir = $CFG->dirroot . "/templates/";	// with an ending "/"
+$CFG->libdir      = $CFG->dirroot . "/lib";	// without an ending "/"
+$CFG->libwww      = $CFG->wwwroot . "/lib";	// without an ending "/"
+$CFG->localedir   = $CFG->dirroot . "/locale/";	// with an ending "/"
+$CFG->productswww = $CFG->wwwroot . "/products/";	// with an ending "/"
+$CFG->productsdir = $CFG->dirroot . "/products/";	// with an ending "/"
+$CFG->images      = $CFG->wwwroot . "/images/";	// with an ending "/"
+$CFG->wordlist    = $CFG->libdir . "/wordlist.txt";
 
 $CFG->pnmpath     = "/usr/bin";	// without an ending "/"
 
@@ -58,10 +55,12 @@ $DB_DEBUG = true;
 $DB_DIE_ON_FAIL = true;
 
 /* load up standard libraries */
-require("$CFG->libdir/stdlib.inc.php");
-require("$CFG->libdir/dblib.inc.php");
-require("$CFG->libdir/pgmarket.inc.php");
-require("$CFG->libdir/cart.inc.php");
+require($CFG->libdir . "/stdlib.inc.php");
+require($CFG->libdir . "/db_" . $CFG->dbms . ".inc.php");	// PHPLib...
+require($CFG->libdir . "/" . $CFG->dbms . "_queries.inc.php");
+require($CFG->libdir . "/pgmarket.inc.php");
+require($CFG->libdir . "/cart.inc.php");
+require($CFG->libdir . "/template.inc.php");
 
 /* setup some global variables */
 $ME = qualified_me();
@@ -109,9 +108,9 @@ if (! isset($SESSION["lang"])) {
 	$SESSION["lang"] = "it";
 //	$SESSION["lang"] = "us";
 }
-$CFG->global = $CFG->localedir.$SESSION["lang"]."/global.inc.php";
+$CFG->globalerror = $CFG->localedir.$SESSION["lang"]."/global-error.inc.php";
 
-include ($CFG->global);
+//include ($CFG->global);
 
 $currency = "Lit";
 $lire2euro = 1936.27;
@@ -196,29 +195,29 @@ $SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (
 $SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
 $SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
 
-$ordersdb[Customer]	= "Cliente             :";
-$ordersdb[Phone]	= "Recapito telefonico :";
-$ordersdb[Address]	= "Indirizzo           :";
-$ordersdb[Cash_On_Delivery] = "Pagamento in Contrassegno";
-$ordersdb[Order] = "Ordine";
-$ordersdb[Username] = "Username";
-$ordersdb[Date] = "Data";
-$ordersdb[Comments] = "Commenti";
-$ordersdb[TOTAL] = "TOTALE";
-$ordersdb[Product] = "Prodotto";
-$ordersdb[Unit_Price] = "Prezzo unitario";
-$ordersdb[Number_of_items] = "Numero di pezzi";
-$ordersdb[Delivery] = "Spedizione";
+$ordersdb["Customer"]	= "Cliente             :";
+$ordersdb["Phone"]	= "Recapito telefonico :";
+$ordersdb["Address"]	= "Indirizzo           :";
+$ordersdb["Cash_On_Delivery"] = "Pagamento in Contrassegno";
+$ordersdb["Order"] = "Ordine";
+$ordersdb["Username"] = "Username";
+$ordersdb["Date"] = "Data";
+$ordersdb["Comments"] = "Commenti";
+$ordersdb["TOTAL"] = "TOTALE";
+$ordersdb["Product"] = "Prodotto";
+$ordersdb["Unit_Price"] = "Prezzo unitario";
+$ordersdb["Number_of_items"] = "Numero di pezzi";
+$ordersdb["Delivery"] = "Spedizione";
 
-$contact[NameOrCompanyName] = "Nome (Ragione Sociale): ";
-$contact[Address] = "Indirizzo:";
-$contact[Phone]         = "Telefono:  ";
-$contact[Fax]           = "Fax:       ";
-$contact[MobilePhone]   = "Cellulare: ";
-$contact[EMail]         = "E-Mail:    ";
-$contact[AuthData]      = "Autorizzazione al trattamento dei dati personali:  ";
-$contact[AuthAdvert]    = "Disponibilita` a ricevere materiale pubblicitario: " ;
-$contact[Message]       = "Messaggio:";
+$contact["NameOrCompanyName"]	= "Nome (Ragione Sociale): ";
+$contact["Address"] = "Indirizzo:";
+$contact["Phone"]		= "Telefono:  ";
+$contact["Fax"]			= "Fax:       ";
+$contact["MobilePhone"]		= "Cellulare: ";
+$contact["EMail"]		= "E-Mail:    ";
+$contact["AuthData"]		= "Autorizzazione al trattamento dei dati personali:  ";
+$contact["AuthAdvert"]		= "Disponibilita` a ricevere materiale pubblicitario: " ;
+$contact["Message"]		= "Messaggio:";
 
 $myday[1] = "Lunedi";
 $myday[2] = "Martedi";
@@ -241,7 +240,4 @@ $mymonth[10] = "Ottobre";
 $mymonth[11] = "Novembre";
 $mymonth[12] = "Dicembre";
 
-/* connect to the database */
-db_connect($CFG->dbhost, $CFG->port, $CFG->dbname, $CFG->dbuser, $CFG->dbpass);
-
 ?>
