@@ -23,18 +23,10 @@ class object {};
 /* setup the configuration object */
 $CFG = new object;
 
-$CFG->dbhost = "localhost";
 $CFG->dbms = "pgsql";	// PostgreSQL
-$CFG->port = "5432";	// PostgreSQL
 //$CFG->dbms = "mysql";	// MySQL
-//$CFG->port = "3306";	// MySQL
-$CFG->dbname = "pgmarket";
-$CFG->dbuser = "postgres";	// PostgreSQL
-$CFG->dbpass = "postgres";	// PostgreSQL
-//$CFG->dbuser = "mysql";	// MySQL
-//$CFG->dbpass = "mysql";	// MySQL
 
-$CFG->myname = "PgMarket 1.5.0 (development)";
+$CFG->myname = "PgMarket 1.5.1 (development)";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
@@ -64,7 +56,8 @@ $DB_DIE_ON_FAIL = true;
 
 /* load up standard libraries */
 require($CFG->libdir . "/stdlib.inc.php");
-require($CFG->libdir . "/" . $CFG->dbms . ".inc.php");
+require($CFG->libdir . "/db_" . $CFG->dbms . ".inc.php");	// PHPLib...
+require($CFG->libdir . "/" . $CFG->dbms . "_queries.inc.php");
 require($CFG->libdir . "/pgmarket.inc.php");
 require($CFG->libdir . "/cart.inc.php");
 require($CFG->libdir . "/template.inc.php");
@@ -243,7 +236,4 @@ $mymonth[10] = "October";
 $mymonth[11] = "November";
 $mymonth[12] = "December";
 
-/* connect to the database */
-db_connect($CFG->dbhost, $CFG->port, $CFG->dbname, $CFG->dbuser, $CFG->dbpass);
-
 ?>
