@@ -46,7 +46,9 @@ function popUp(menuName,on) {
 
 <?
 
-build_catbrowser_js($categories);
+$qid_bcjs = new DB_Sql;
+build_catbrowser_js(&$qid_bcjs, $categories);
+$qid_bcjs->close();
 $categories = ".Top^" . $CFG->wwwroot . "/shopping/\n" . $categories;
 //echo $categories;
 
