@@ -34,13 +34,37 @@ function load_user_profile() {
 	global $SESSION;
 	
 	$username = $SESSION["user"]["username"];
-	$qid = db_query("SELECT firstname, lastname, usertype, priv,
-				fiscalcode, address, number, city, country, zip_code,
-				phone, fax, mobilephone, email, authdata, acceptadvert, notes
-			FROM users
-			WHERE username = '$username'
-			");
-	return db_fetch_array($qid, 0);
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT firstname, lastname, usertype, priv,
+			fiscalcode, address, number, city, country, zip_code,
+			phone, fax, mobilephone, email, authdata, acceptadvert, notes
+		FROM users
+		WHERE username = '$username'
+	");
+	$qid->next_record();
+	$arr = array();
+	$arr["firstname"] = $qid->f("firstname");
+	$arr["lastname"] = $qid->f("lastname");
+	$arr["usertype"] = $qid->f("usertype");
+	$arr["priv"] = $qid->f("priv");
+	$arr["fiscalcode"] = $qid->f("fiscalcode");
+	$arr["address"] = $qid->f("address");
+	$arr["number"] = $qid->f("number");
+	$arr["city"] = $qid->f("city");
+	$arr["country"] = $qid->f("country");
+	$arr["zip_code"] = $qid->f("zip_code");
+	$arr["phone"] = $qid->f("phone");
+	$arr["fax"] = $qid->f("fax");
+	$arr["mobilephone"] = $qid->f("mobilephone");
+	$arr["email"] = $qid->f("email");
+	$arr["authdata"] = $qid->f("authdata");
+	$arr["acceptadvert"] = $qid->f("acceptadvert");
+	$arr["notes"] = $qid->f("notes");
+
+	return $arr;
+//	return db_fetch_array($qid, 0);
 }
 
 function require_login() {
@@ -78,24 +102,39 @@ function has_priv($priv) {
 	return $SESSION["user"]["priv"] == $priv;
 }
 
-function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
-/* recursively go through the category tree, starting at a parent, and
- * drill down, printing options for a selection list box.  preselected
- * items are marked as being selected.  this is not an efficient algorithm
- * because it has to issue one query per category!!  it's only used because it
- * is easy to understand.
- */
+function build_category_path(&$qid, $id=1, &$category_path) {
+// puts recursively in $category_path the path of the product categories,
+// starting from the top to the category specified by $id
 
-	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' ORDER BY special_level, name");
+	global $CFG;
 
-	$numr = db_num_rows($qid);
-	for ($i=0;$i<$numr;$i++) {
-		$cat =  db_fetch_object($qid, $i);
-		$selected = in_array($cat->id, $preselected) ? "selected" : "";
-		$output .= "<option value=\"" . ov($cat->id) . "\" $selected>" . $indent . ov($cat->name);
-		if ($cat->id != $parent) {
-			build_category_tree($output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
-		}
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT parent_id, name
+		FROM categories
+		WHERE id = '$id'
+	");
+//	if (db_num_rows($qid)) {
+	if ($qid->num_rows()) {
+//		list($parent, $name) = db_fetch_row($qid, 0);
+		$qid->next_record();
+		$parent = $qid->f("parent_id");
+		$name = $qid->f("name");
+		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
+	} else {
+		$parent = 1;
+		$name = "";
+	}
+//	$qid->close();
+
+	if ($parent > 1) {
+		$category_path = " &gt; " . $name . $category_path;
+		build_category_path(&$qid, $parent, &$category_path);
+	} elseif ($id > 1) {
+		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name . $category_path;
+	} elseif ($id == 1) {
+		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
 	}
 }
 
@@ -107,19 +146,36 @@ function build_catbrowser(&$output, $parent=1, $indent="..") {
  */
 	global $CFG, $SESSION;
 
-	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY special_level, name");
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT id, name
+		FROM categories
+		WHERE parent_id = '$parent' AND id <> 1
+		ORDER BY special_level, name
+	");
 
-	$numr = db_num_rows($qid);
+	$cat = array();
+	$numr = $qid->num_rows();
 	for ($i=0;$i<$numr;$i++) {
-		$cat =  db_fetch_object($qid, $i);
-		$output .= $indent . stripslashes($cat->name) . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^" . $SESSION["catbrowser_target"] . "\n";
-		if ($cat->id != $parent) {
-			build_catbrowser($output, $cat->id, $indent.".");
+		$qid->seek($i);
+		$qid->next_record();
+		$cat[$i]["id"] = $qid->f("id");
+		$cat[$i]["name"] = $qid->f("name");
+	}
+	$qid->close();
+
+//	$numr = db_num_rows($qid);
+	for ($i=0;$i<$numr;$i++) {
+//		$cat =  db_fetch_object($qid, $i);
+		$output .= $indent . stripslashes($cat[$i]["name"]) . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat[$i]["id"] . "^" . $SESSION["catbrowser_target"] . "\n";
+		if ($cat[$i]["id"] != $parent) {
+			build_catbrowser($output, $cat[$i]["id"], $indent.".");
 		}
 	}
 }
 
-function build_catbrowser_js(&$output, $parent=1, $indent="..") {
+function build_catbrowser_js(&$qid, &$output, $parent=1, $indent="..") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
@@ -127,17 +183,72 @@ function build_catbrowser_js(&$output, $parent=1, $indent="..") {
  */
 	global $CFG;
 
-	$qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY special_level, name");
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT id, name
+		FROM categories
+		WHERE parent_id = '$parent' AND id <> 1
+		ORDER BY special_level, name
+	");
 
-	$numr = db_num_rows($qid);
+	$cat = array();
+	$numr = $qid->num_rows();
 	for ($i=0;$i<$numr;$i++) {
-		$cat =  db_fetch_object($qid, $i);
+		$qid->seek($i);
+		$qid->next_record();
+		$cat[$i]["id"] = $qid->f("id");
+		$cat[$i]["name"] = $qid->f("name");
+	}
+//	$qid->close();
+
+//	$numr = db_num_rows($qid);
+	for ($i=0;$i<$numr;$i++) {
+//		$cat =  db_fetch_object($qid, $i);
 //		if (getenv("QUERY_STRING") == "")
-			$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?id=" . $cat->id . "\n";
+			$output .= $indent . $cat[$i]["name"] . "^" . $CFG->wwwroot . "/shopping/?id=" . $cat[$i]["id"] . "\n";
 //		else
-//			$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "\n";
-		if ($cat->id != $parent) {
-			build_catbrowser_js($output, $cat->id, $indent.".");
+//			$output .= $indent . $cat[$i]["name"] . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat[$i]["id"] . "\n";
+		if ($cat[$i]["id"] != $parent) {
+			build_catbrowser_js(&$qid, $output, $cat[$i]["id"], $indent.".");
+		}
+	}
+}
+
+function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
+/* recursively go through the category tree, starting at a parent, and
+ * drill down, printing options for a selection list box.  preselected
+ * items are marked as being selected.  this is not an efficient algorithm
+ * because it has to issue one query per category!!  it's only used because it
+ * is easy to understand.
+ */
+
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT id, name
+		FROM categories
+		WHERE parent_id = '$parent'
+		ORDER BY special_level, name
+	");
+
+	$cat = array();
+	$numr = $qid->num_rows();
+	for ($i=0;$i<$numr;$i++) {
+		$qid->seek($i);
+		$qid->next_record();
+		$cat[$i]["id"] = $qid->f("id");
+		$cat[$i]["name"] = $qid->f("name");
+	}
+	$qid->close();
+
+//	$numr = db_num_rows($qid);
+	for ($i=0;$i<$numr;$i++) {
+//		$cat =  db_fetch_object($qid, $i);
+		$selected = in_array($cat[$i]["id"], $preselected) ? "selected" : "";
+		$output .= "<option value=\"" . ov($cat[$i]["id"]) . "\" $selected>" . $indent . ov($cat[$i]["name"]);
+		if ($cat[$i]["id"] != $parent) {
+			build_category_tree($output, $preselected, $cat[$i]["id"], $indent."&nbsp;&nbsp;");
 		}
 	}
 }
@@ -192,62 +303,56 @@ function reset_user_password($username) {
 	global $CFG;
 	global $SESSION;
 
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->begin();
+
 	/* load up the user record */
-	$qid = db_query("SELECT username, priv, firstname, lastname, email FROM users WHERE username = '$username'");
-	$user = db_fetch_object($qid, 0);
-	if ($user->priv == "admin" || !has_priv("admin")) {
+	$qid->Query("
+		SELECT username, priv, firstname, lastname, email
+		FROM users
+		WHERE username = '$username'
+	");
+//	$user = db_fetch_object($qid, 0);
+	$qid->next_record();
+	if ($qid->f("priv") == "admin" || !has_priv("admin")) {
 		return 1;
 	}
 
 	/* reset the password */
 	$newpassword = generate_password();
-	$qid = db_query("UPDATE users SET password = '" . md5($newpassword) ."' WHERE username = '$username'");
 
 	/* email the user with the new account information */
 	$var = new Object;
-	$var->username = $user->username;
-	$var->fullname = $user->firstname . " " . $user->lastname;
+	$var->username = $qid->f("username");
+	$var->fullname = $qid->f("firstname") . " " . $qid->f("lastname");
 	$var->newpassword = $newpassword;
 	$var->support = $CFG->support;
 	$var->myname = $CFG->myname;
 
 	$emailbody = read_template($CFG->templatedir.$SESSION["lang"]."/reset_password.ihtml", $var);
 
+	$appoggio = $qid->f("email");
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE users
+		SET password = '" . md5($newpassword) ."'
+		WHERE username = '$username'
+	");
 	mail(
-		"$var->fullname <$user->email>",
+		"$var->fullname <$appoggio>",
 		$CFG->myname . " Account Information",
 		$emailbody,
-		"From: $var->support");
+		"From: $var->support"
+	);
+
+	$qid->commit();
+	$qid->close();
 
 	return 0;
 }
 
-function build_category_path($id=1, &$category_path) {
-// puts recursively in $category_path the path of the product categories,
-// starting from the top to the category specified by $id
-
-	global $CFG;
-
-	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id'");
-	if (db_num_rows($qid)) {
-		list($parent, $name) = db_fetch_row($qid, 0);
-		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
-	} else {
-		$parent = 1;
-		$name = "";
-	}
-
-	if ($parent > 1) {
-		$category_path = " &gt; " . $name . $category_path;
-		build_category_path($parent, &$category_path);
-	} elseif ($id > 1) {
-		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name . $category_path;
-	} elseif ($id == 1) {
-		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
-	}
-}
-
-function get_cart_items() {
+function get_cart_items(&$qid) {
 /* return a $qid of all the items in the shopping cart */
 
 	global $SESSION, $CART;
@@ -257,11 +362,11 @@ function get_cart_items() {
 		return false;
 	}
 
-	return db_query ("
-			SELECT p.*, i.iva
-			FROM products p, iva i
-			WHERE p.iva_id = i.id AND p.id IN ($in_clause)
-			");
+	$qid->Query("
+		SELECT p.*, i.iva
+		FROM products p, iva i
+		WHERE p.iva_id = i.id AND p.id IN ($in_clause)
+	");
 }
 
 //function chop_ccnum($ccnum) {
@@ -323,26 +428,6 @@ function return_star() {
 	return "<font color=\"#ff0000\">*</font>";
 }
 
-function get_brand($brand_id) {
-// returns the brand associated with the given brand_id
-
-	$qid = db_query("
-	SELECT name FROM brands WHERE id = $brand_id
-	");
-	$arr = db_fetch_array($qid, 0);
-	return $arr[0];
-}
-
-function get_iva($iva_id) {
-// returns the iva associated with the given iva_id
-
-	$qid = db_query("
-	SELECT iva FROM iva WHERE id = $iva_id
-	");
-	$arr = db_fetch_array($qid, 0);
-	return $arr[0];
-}
-
 function validate_username($username, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
@@ -925,14 +1010,16 @@ function product_id_exists($product_id, &$errors, &$msg) {
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
 
-	$qid = db_query("
-	SELECT id FROM products WHERE id = '$product_id'
-	");
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("SELECT id FROM products WHERE id = '$product_id'");
 
-	if (db_num_rows($qid) > 0) {
+//	if (db_num_rows($qid) > 0) {
+	if ($qid->num_rows() > 0) {
 		$errors->product_exists = true;
 		$msg .= "<li>".$the_product_id.$product_id.$already_exists;
 	}
+	$qid->close();
 }
 
 function validate_product_name($product_name, &$errors, &$msg) {
