@@ -61,39 +61,6 @@ function p($var) {
 	echo empty($var) ? "" : htmlSpecialChars(stripslashes($var));
 }
 
-function db_query_loop($query, $prefix, $suffix, $found_str, $default="") {
-/* this is an internal function and normally isn't called by the user.  it
- * loops through the results of a select query $query and prints HTML
- * around it, for use by things like listboxes and radio selections
- *
- * NOTE: this function uses dblib.php */
-
-	$output = "";
-	$result = db_query($query);
-	$numr = db_num_rows($result);
-	for ($i=0; $i<$numr; $i++) {
-		list($val, $label) = db_fetch_row($result, $i);
-		if (is_array($default))
-			$selected = empty($default[$val]) ? "" : $found_str;
-		else
-			$selected = $val == $default ? $found_str : "";
-
-		$output .= "$prefix value='$val' $selected>$label$suffix";
-	}
-
-	return $output;
-}
-
-function db_listbox($query, $default="", $suffix="\n") {
-/* generate the <option> statements for a <select> listbox, based on the
- * results of a SELECT query ($query).  any results that match $default
- * are pre-selected, $default can be a string or an array in the case of
- * multi-select listboxes.  $suffix is printed at the end of each <option>
- * statement, and normally is just a line break */
-
-	return db_query_loop($query, "<option", $suffix, "selected", $default);
-}
-
 function strip_querystring($url) {
 /* takes a URL and returns it without the querystring portion */
 
@@ -159,7 +126,7 @@ function match_referer($good_referer = "") {
 
 function redirect($url, $message="", $delay=0) {
 /* redirects to a new URL using meta tags */
-	echo "<meta http-equiv='Refresh' content='$delay; url=$url'>";
+	echo "<meta http-equiv='Refresh' content='$delay; url=$url" . "?" . SID . "'>";
 	if (!empty($message)) echo "<div style='font-family: Arial, Sans-serif; font-size: 12pt;' align=center>$message</div>";
 	die;
 }
