@@ -19,6 +19,7 @@
  *****************************************************************************/
 
 include("application.inc.php");
+include ($CFG->globalerror);
 
 /* form has been submitted, check if it the user login information is correct */
 if (match_referer() && isset($HTTP_POST_VARS)) {
@@ -37,7 +38,7 @@ if (match_referer() && isset($HTTP_POST_VARS)) {
 		/* if wantsurl is set, that means we came from a page that required
 		 * log in, so let's go back there.  otherwise go back to the main page */
 		$goto = empty($SESSION["wantsurl"]) ? $CFG->firstpage : $SESSION["wantsurl"];
-		header("Location: $goto");
+		header("Location: $goto" . "?" . SID);
 		die;
 
 	} else {
@@ -72,15 +73,27 @@ function verify_login($username, $password) {
 /* verify the username and password.  if it is a valid login, return an array
  * with the username, firstname, lastname, and email address of the user */
 
-	$qid = db_query("
+	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
 		SELECT username, usertype, firstname, lastname, fiscalcode, email, priv
 		FROM users
 		WHERE username = '$username' AND password = '$password'
 	");
 
-	$numr = db_num_rows($qid);
-	if ( $numr > 0 ) {
-		return db_fetch_array($qid, 0);
+//	$numr = db_num_rows($qid);
+//	if ( $numr > 0 ) {
+	if ($qid->num_rows() > 0) {
+//		return db_fetch_array($qid, 0);
+		$qid->next_record();
+		$user["username"] = $qid->f("username");
+		$user["usertype"] = $qid->f("usertype");
+		$user["firstname"] = $qid->f("firstname");
+		$user["lastname"] = $qid->f("lastname");
+		$user["fiscalcode"] = $qid->f("fiscalcode");
+		$user["email"] = $qid->f("email");
+		$user["priv"] = $qid->f("priv");
+		return $user;
 	} else {
 		return false;
 	}
