@@ -129,20 +129,23 @@ function create_order_ca(&$order, &$emailbody) {
 	$Dateusec = gettimeofday();
 	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
-	$qid = db_query("
-	INSERT INTO ordersca (
-		id, username, date, fromip, custinfo, notes, amount, delivery
-	) VALUES (
-		 '$orderid'
-		,'{$SESSION["user"]["username"]}'
-		,'$Date'
-		,'$FromIP'
-		,'$custinfo'
-		,'$order->comments'
-		,'{$CART->grandtotal}'
-		,'{$CART->delivery}'
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO ordersca (
+			id, username, date, fromip, custinfo, notes, amount, delivery
+		) VALUES (
+			 '$orderid'
+			,'{$SESSION["user"]["username"]}'
+			,'$Date'
+			,'$FromIP'
+			,'$custinfo'
+			,'$order->comments'
+			,'{$CART->grandtotal}'
+			,'{$CART->delivery}'
 	)");
 
 	$order_comments = stripslashes ($order->comments);
@@ -154,33 +157,44 @@ function create_order_ca(&$order, &$emailbody) {
 		. "\n\n" . $ordersdb[TOTAL] . ": " . formatted_price_text ($CART->grandtotal) . "\n";
 
 	/* now add the shopping cart items into the order_items table */
-	$qid = get_cart_items();
-	$numr = db_num_rows($qid);
-	for ($i=0; $i<$numr; $i++) {
-		$item = db_fetch_object($qid, $i);
-		db_query("
-		INSERT INTO order_items (
-			order_id, product_id, price, iva, weight, qty
-		) VALUES (
-			 '$orderid'
-			,'$item->id'
-			,'$item->price'
-			,'$item->iva'
-			,'$item->weight'
-			,'{$CART->items["$item->id"]}'
+//	$qid = get_cart_items();
+	get_cart_items(&$qid);
+//	$numr = db_num_rows($qid);
+//	for ($i=0; $i<$numr; $i++) {
+	$qid_null = new DB_Sql;
+	$qid_prod_id = new DB_Sql;
+	while ($qid->next_record()) {
+//		$item = db_fetch_object($qid, $i);
+		$qid_id = $qid->f("id");
+		$qid_price = $qid->f("price");
+		$qid_iva = $qid->f("iva");
+		$qid_weight = $qid->f("weight");
+//		db_query("
+		$qid_null->Query("
+			INSERT INTO order_items (
+				order_id, product_id, price, iva, weight, qty
+			) VALUES (
+				 '$orderid'
+				,'$qid_id'
+				,'$qid_price'
+				,'$qid_iva'
+				,'$qid_weight'
+				,'{$CART->items["$qid_id"]}'
 		)");
-		$qid_prod_id = db_query("
-		SELECT name
-		FROM products
-		WHERE id = '$item->id'
+//		$qid_prod_id = db_query("
+		$qid_prod_id->Query("
+			SELECT name
+			FROM products
+			WHERE id = '$qid->f(id)'
 		");
-		$row = db_fetch_object($qid_prod_id, 0);
-		$emailbody .= "\n" . $ordersdb[Product] . " " . $item->id . " - " . $row->name
-			. "\n" . $ordersdb[Unit_Price] . ": " . formatted_price_text ($item->price)
-			. "\n" . $ordersdb[Number_of_items] . ": " . $CART->items["$item->id"] . "\n";
+//		$row = db_fetch_object($qid_prod_id, 0);
+		$emailbody .= "\n" . $ordersdb[Product] . " " . $qid->f(id) . " - " . $qid_prod_id->f(name)
+			. "\n" . $ordersdb[Unit_Price] . ": " . formatted_price_text ($qid->f(price))
+			. "\n" . $ordersdb[Number_of_items] . ": " . $CART->items["$qid->f(id)"] . "\n";
 	}
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	$emailbody .= "\n" . $ordersdb[Delivery] . ": " . formatted_price_text ($CART->delivery);
 
@@ -209,42 +223,54 @@ function create_order_cc(&$order, $passwordric) {
 	$Dateusec = gettimeofday();
 	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;
 
-	$qid = db_begin();
+	$qid = new DB_Sql;
+//	$qid = db_begin();
+	$qid->begin();
 
-	$qid = db_query("
-	INSERT INTO orderscc (
-		id, username, date, fromip, custinfo, notes, amount, delivery, otpric
-	) VALUES (
-		 '$orderid'
-		,'{$SESSION["user"]["username"]}'
-		,'$Date'
-		,'$FromIP'
-		,'$custinfo'
-		,'$order->comments'
-		,'{$CART->grandtotal}'
-		,'{$CART->delivery}'
-		,'$passwordric'
+//	$qid = db_query("
+	$qid->Query("
+		INSERT INTO orderscc (
+			id, username, date, fromip, custinfo, notes, amount, delivery, otpric
+		) VALUES (
+			 '$orderid'
+			,'{$SESSION["user"]["username"]}'
+			,'$Date'
+			,'$FromIP'
+			,'$custinfo'
+			,'$order->comments'
+			,'{$CART->grandtotal}'
+			,'{$CART->delivery}'
+			,'$passwordric'
 	)");
 
 	/* now add the shopping cart items into the order_items table */
-	$qid = get_cart_items();
-	$numr = db_num_rows($qid);
-	for ($i=0; $i<$numr; $i++) {
-		$item = db_fetch_object($qid, $i);
-		db_query("
-		INSERT INTO order_items (
-			order_id, product_id, price, iva, weight, qty
-		) VALUES (
-			 '$orderid'
-			,'$item->id'
-			,'$item->price'
-			,'$item->iva'
-			,'$item->weight'
-			,'{$CART->items["$item->id"]}'
+//	$qid = get_cart_items();
+	get_cart_items(&$qid);
+//	$numr = db_num_rows($qid);
+//	for ($i=0; $i<$numr; $i++) {
+	$qid_null = new DB_Sql;
+	while ($qid->next_record()) {
+//		$item = db_fetch_object($qid, $i);
+		$qid_id = $qid->f("id");
+		$qid_price = $qid->f("price");
+		$qid_iva = $qid->f("iva");
+		$qid_weight = $qid->f("weight");
+//		db_query("
+		$qid_null->Query("
+			INSERT INTO order_items (
+				order_id, product_id, price, iva, weight, qty
+			) VALUES (
+				 '$orderid'
+				,'$qid_id'
+				,'$qid_price'
+				,'$qid_iva'
+				,'$qid_weight'
+				,'{$CART->items["$qid_id"]}'
 		)");
 	}
 
-	$qid = db_commit();
+//	$qid = db_commit();
+	$qid->commit();
 
 	return $orderid;
 }
