@@ -20,18 +20,26 @@
 
 include("../application.inc.php");
 
+$qid = new DB_Sql;
+
 if (!empty($product_id)) {
 	if (empty($id)) {	// category not specified
-		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
-		if (db_num_rows($qid)) {
-			list($id) = db_fetch_row($qid, 0);
+//		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
+		$qid->Query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
+//		if (db_num_rows($qid)) {
+		if ($qid->num_rows()) {
+//			list($id) = db_fetch_row($qid, 0);
+			$qid->next_record();
+			$id = $qid->f("category_id");
 		} else {
 			header("Location: $CFG->firstpage");
 			die;
 		}
 	} else {
-		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id' AND category_id = '$id'");
-		if (!db_num_rows($qid)) {
+//		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id' AND category_id = '$id'");
+		$qid->Query("SELECT category_id FROM products_categories WHERE product_id = '$product_id' AND category_id = '$id'");
+//		if (!db_num_rows($qid)) {
+		if (!($qid->num_rows())) {
 			header("Location: $CFG->firstpage");
 			die;
 		}
@@ -41,26 +49,30 @@ if (!empty($product_id)) {
 	die;
 }
 
-$qid = db_query("
-		SELECT
-			 p.id AS product_id
-			,p.name AS name
-			,p.price
-			,p.discount
-			,p.discqty
-			,p.weight
-			,p.extended_description
-			,p.imagetype
-			,p.imagewidth
-			,p.imageheight
-			,b.name AS bname
-			,i.iva
-		FROM products p, brands b, iva i
-		WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
-		");
+//$qid = db_query("
+$qid->Query("
+	SELECT
+		 p.id AS product_id
+		,p.name AS name
+		,p.price
+		,p.discount
+		,p.discqty
+		,p.weight
+		,p.extended_description
+		,p.imagetype
+		,p.imagewidth
+		,p.imageheight
+		,b.name AS bname
+		,i.iva
+	FROM products p, brands b, iva i
+	WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
+");
 
-if (db_num_rows($qid) > 0) {
-	$prod = db_fetch_object($qid, 0);
+//if (db_num_rows($qid) > 0) {
+if ($qid->num_rows() > 0) {
+//	$prod = db_fetch_object($qid, 0);
+	$qid->next_record();
+	$prod = true;
 } else {
 	$prod = false;
 }
@@ -78,7 +90,9 @@ $t->set_var(array("product_blck" => ""));
 $t->set_block("page", "noproduct", "noproduct_blck");
 $t->set_var(array("noproduct_blck" => ""));
 if ($prod) {
-	build_category_path($id, $category_path);
+	$qid_bcp = new DB_Sql;
+	build_category_path(&$qid_bcp, $id, $category_path);
+	$qid_bcp->close();
 	$t->set_var("category_path", $category_path);
 
 	$t->set_block("product", "brand_used", "brand_used_blck");
@@ -97,41 +111,41 @@ if ($prod) {
 	$t->set_var("notadminprodimage_blck", "");
 	$t->set_var(array(
 		"category_id"		=> $id,
-		"product_id"		=> $prod->product_id,
-		"name"			=> ov($prod->name),
-		"price"			=> $prod->price,
-		"fprice"		=> formatted_price($prod->price),
-		"extended_description"	=> ovwbr($prod->extended_description),
-		"imagetype"		=> $prod->imagetype
+		"product_id"		=> $qid->f("product_id"),
+		"name"			=> ov($qid->f("name")),
+		"price"			=> $qid->f("price"),
+		"fprice"		=> formatted_price($qid->f("price")),
+		"extended_description"	=> ovwbr($qid->f("extended_description")),
+		"imagetype"		=> $qid->f("imagetype"),
 	));
-	if ($SESSION["brand_used"] && $prod->bname != "") {
-		$t->set_var("bname", ov($prod->bname));
+	if ($SESSION["brand_used"] && $qid->f("bname") != "") {
+		$t->set_var("bname", ov($qid->f("bname")));
 		$t->parse("brand_used_blck", "brand_used", true);
 	}
 	if ($SESSION["iva_used"]) {
-		$t->set_var("iva", ov($prod->iva));
+		$t->set_var("iva", ov($qid->f("iva")));
 		$t->parse("iva_used_blck", "iva_used", true);
 	}
-	if ($prod->discount > 0) {
-		$t->set_var("discount", $prod->discount);
-		if ($prod->discqty > 1) {
-			$t->set_var("discqty", $prod->discqty);
+	if ($qid->f("discount") > 0) {
+		$t->set_var("discount", $qid->f("discount"));
+		if ($qid->f("discqty") > 1) {
+			$t->set_var("discqty", $qid->f("discqty"));
 			$t->parse("discqty_block_blck", "discqty_block", true);
 		}
 		$t->parse("discount_block_blck", "discount_block", true);
 	}
 	if ($SESSION["weight_used"]) {
 		$t->set_var(array(
-			"weight"	=> $prod->weight,
-			"fweight"	=> formatted_weight($prod->weight)
+			"weight"	=> $qid->f("weight"),
+			"fweight"	=> formatted_weight($qid->f("weight"))
 		));
 		$t->parse("weight_used_blck", "weight_used", true);
 	}
-	if (file_exists($CFG->productsdir.string_cleanup($prod->product_id).".".$prod->imagetype)) {
+	if (file_exists($CFG->productsdir.string_cleanup($qid->f("product_id")).".".$qid->f("imagetype"))) {
 		$t->set_var(array(
-			"imagefilename" => string_cleanup($prod->product_id),
-			"imagewidth"    => $prod->imagewidth,
-			"imageheight"   => $prod->imageheight
+			"imagefilename" => string_cleanup($qid->f("product_id")),
+			"imagewidth"    => $qid->f("imagewidth"),
+			"imageheight"   => $qid->f("imageheight")
 		));
 		if (has_priv("admin")) {
 			$t->set_var("wwwroot", $CFG->wwwroot);
