@@ -12,10 +12,26 @@ if (empty($stringtsf_stripped)) {
 }
 
 if (!isset($page_number) || $dbchanged) {
-	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
-	$SESSION["numr"] = db_num_rows($qid_p);
+//	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
+	find_products(&$qid_p, &$stringtsf_stripped, $case_sensitive, $concatenation);
+//	$SESSION["numr"] = db_num_rows($qid_p);
+	$SESSION["numr"] = $qid_p->num_rows();
 	for ($i=0; $i<$SESSION["numr"]; $i++) {
-		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
+//		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
+		$qid_p->seek($i);
+		$qid_p->next_record();
+		$SESSION["searchres"][$i]["id"] = $qid_p->f("id");
+		$SESSION["searchres"][$i]["name"] = $qid_p->f("name");
+		$SESSION["searchres"][$i]["price"] = $qid_p->f("price");
+		$SESSION["searchres"][$i]["description"] = $qid_p->f("description");
+		$SESSION["searchres"][$i]["thumbwidth"] = $qid_p->f("thumbwidth");
+		$SESSION["searchres"][$i]["thumbheight"] = $qid_p->f("thumbheight");
+		$SESSION["searchres"][$i]["special_level"] = $qid_p->f("special_level");
+		$SESSION["searchres"][$i]["bname"] = $qid_p->f("bname");
+		$SESSION["searchres"][$i]["iva"] = $qid_p->f("iva");
+		$SESSION["searchres"][$i]["discount"] = $qid_p->f("discount");
+		$SESSION["searchres"][$i]["discqty"] = $qid_p->f("discqty");
+		$SESSION["searchres"][$i]["weight"] = $qid_p->f("weight");
 	}
 	if (!isset($page_number)) {
 		$page_number = 1;
