@@ -21,13 +21,15 @@
 include("../application.inc.php");
 require_login();
 
+$qid = new DB_Sql;
+
 /* form has been submitted, check if it the user login information is correct */
 if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	$frm = $HTTP_POST_VARS;
-	$errormsg = validate_form($frm, $errors);
+	$errormsg = validate_form(&$qid, $frm, $errors);
 
 	if (empty($errormsg)) {
-		update_password($frm["newpassword"]);
+		update_password(&$qid, $frm["newpassword"]);
 		$noticemsg = "Password_Change_Successful";
 	}
 }
@@ -57,7 +59,7 @@ include("$CFG->dirroot"."/footer.php");
  * FUNCTIONS
  *****************************************************************************/
 
-function validate_form(&$frm, &$errors) {
+function validate_form(&$qid, &$frm, &$errors) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
@@ -70,7 +72,7 @@ function validate_form(&$frm, &$errors) {
 		$errors->oldpassword = true;
 		$msg .= $no_old_password;
 
-	} elseif (! password_valid($frm["oldpassword"])) {
+	} elseif (! password_valid(&$qid, $frm["oldpassword"])) {
 		$errors->oldpassword = true;
 		$msg .= $old_password_not_valid;
 
@@ -91,29 +93,38 @@ function validate_form(&$frm, &$errors) {
 	return $msg;
 }
 
-function password_valid($password) {
+function password_valid(&$qid, $password) {
 /* return true if the user's password is valid */
 
 	global $SESSION;
 	
 	$username = $SESSION["user"]["username"];
 
-	$qid = db_query("SELECT 1
-			FROM users
-			WHERE username = '$username' AND password = '$password'");
-	return db_num_rows($qid);
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		SELECT 1
+		FROM users
+		WHERE username = '$username' AND password = '$password'
+	");
+//	return db_num_rows($qid);
+	return $qid->num_rows();
 }
 
-function update_password($newpassword) {
+function update_password(&$qid, $newpassword) {
 /* set the user's password to the new one */
 
 	global $SESSION, $CFG;
 	
 	$username = $SESSION["user"]["username"];
 
-	$qid = db_query("UPDATE users
-			SET password = '$newpassword'
-			WHERE username = '$username'");
+//	$qid = new DB_Sql;
+//	$qid = db_query("
+	$qid->Query("
+		UPDATE users
+		SET password = '$newpassword'
+		WHERE username = '$username'
+	");
 
 	if (has_priv("admin")) {
 		mail(
