@@ -50,77 +50,40 @@ function show_order_details($id, $username) {
 	global $page_number;
 //	include ($CFG->globalerror);
 
-	$qid_order = db_query("
-	SELECT o.*, os.name AS state_name
-	FROM ordersca o, orders_states os
-	WHERE o.state_id = os.id AND o.id = '$id'
+	$qid_order = new DB_Sql;
+//	$qid_order = db_query("
+	$qid_order->Query("
+		SELECT o.*, os.name AS state_name
+		FROM ordersca o, orders_states os
+		WHERE o.state_id = os.id AND o.id = '$id'
 	");
-	if (db_num_rows($qid_order) < 1) {
+//	if (db_num_rows($qid_order) < 1) {
+	if ($qid_order->num_rows() < 1) {
 		$t = new Template();
 		$t->set_file(array("page" => "templates/no_such_order.ihtml"));
 		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
 		$t->pparse("out", "page");
 //		include("templates/no_such_order.ihtml");
 		return;
+	} else {
+		$qid_order->next_record();
 	}
 
-	if ($CFG->dbms == "pgsql") {
-		$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi, products p
-		WHERE	oi.product_id = p.id AND order_id = '$id'
-		UNION
-		SELECT
-			 oi.product_id
-			,'-' as name
-			,0 as curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM order_items oi
-		WHERE order_id = '$id' AND
-			NOT EXISTS
-			(
-				SELECT
-					id
-				FROM products
-				WHERE id = oi.product_id
-			)
-		");
-	} else if ($CFG->dbms == "mysql") {
-		$qid_items = db_query("
-		SELECT
-			 oi.product_id
-			,p.name
-			,p.price AS curr_price
-			,oi.price AS purchase_price
-			,oi.iva AS purchase_iva
-			,oi.weight AS purchase_weight
-			,oi.qty
-			,oi.price * oi.qty AS total
-		FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
-		WHERE	order_id = '$id'
-		");
-	}
+	$qid_items = new DB_Sql;
+	get_order_items(&$qid_items, $id);
 
-	$order = db_fetch_object($qid_order, 0);
+//	$order = db_fetch_object($qid_order, 0);
 
-	$qid_user = db_query("
-	SELECT usertype, fiscalcode, email
-	FROM users
-	WHERE username = '$order->username'
+	$qid_user = new DB_Sql;
+//	$qid_user = db_query("
+	$appoggio = $qid_order->f("username");
+	$qid_user->Query("
+		SELECT usertype, fiscalcode, email
+		FROM users
+		WHERE username = '$appoggio'
 	");
-	$user = db_fetch_object($qid_user, 0);
+//	$user = db_fetch_object($qid_user, 0);
+	$qid_user->next_record();
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_details.ihtml"));
@@ -129,16 +92,16 @@ function show_order_details($id, $username) {
 	$t->set_var("ME", $ME);
 	$t->set_var(array(
 			"order_id"		=> ov($id),
-			"order_state_name"	=> $order->state_name,
-			"order_date"		=> ov($order->date),
-			"order_amount"		=> $order->amount,
-			"order_famount"		=> formatted_price($order->amount),
-			"order_custinfo"	=> nl2br(ov($order->custinfo)),
-			"user_fiscalcode"	=> $user->fiscalcode,
-			"user_email"		=> $user->email,
-			"order_notes"		=> nl2br(ov($order->notes))
+			"order_state_name"	=> $qid_order->f("state_name"),
+			"order_date"		=> ov($qid_order->f("date")),
+			"order_amount"		=> $qid_order->f("amount"),
+			"order_famount"		=> formatted_price($qid_order->f("amount")),
+			"order_custinfo"	=> nl2br(ov($qid_order->f("custinfo"))),
+			"user_fiscalcode"	=> $qid_user->f("fiscalcode"),
+			"user_email"		=> $qid_user->f("email"),
+			"order_notes"		=> nl2br(ov($qid_order->f("notes")))
 	));
-	if ($user->usertype == "pf") {
+	if ($qid_user->f("usertype") == "pf") {
 		$t->set_block("page", "usertype_pf", "usertype_pf_blck");
 		$t->set_var(array("usertype_pf_blck", ""));
 		$t->parse("usertype_pf_blck", "usertype_pf", true);
@@ -159,31 +122,32 @@ function show_order_details($id, $username) {
 	$t->set_var("item_rows", "");
 		$t->set_block("item_row", "weight_used_row", "weight_used_row_blck");
 		$t->set_block("item_row", "iva_used_row", "iva_used_row_blck");
-	$numr = db_num_rows($qid_items);
-	for ($i=0; $i<$numr; $i++) {
+//	$numr = db_num_rows($qid_items);
+//	for ($i=0; $i<$numr; $i++) {
+	while ($qid_items->next_record()) {
 		$t->set_var("weight_used_row_blck", "");
 		$t->set_var("iva_used_row_blck", "");
-		$prod = db_fetch_object($qid_items, $i);
+//		$prod = db_fetch_object($qid_items, $i);
 		$t->set_var(array(
-				"prod_product_id"	=> ov($prod->product_id),
-				"prod_name"		=> ov($prod->name),
-				"prod_curr_price"	=> $prod->curr_price,
-				"prod_fcurr_price"	=> formatted_price($prod->curr_price),
-				"prod_purchase_price"	=> $prod->purchase_price,
-				"prod_fpurchase_price"	=> formatted_price($prod->purchase_price),
-				"prod_qty"		=> $prod->qty,
-				"prod_total"		=> $prod->total,
-				"prod_ftotal"		=> formatted_price($prod->total)
+				"prod_product_id"	=> ov($qid_items->f("product_id")),
+				"prod_name"		=> ov($qid_items->f("name")),
+				"prod_curr_price"	=> $qid_items->f("curr_price"),
+				"prod_fcurr_price"	=> formatted_price($qid_items->f("curr_price")),
+				"prod_purchase_price"	=> $qid_items->f("purchase_price"),
+				"prod_fpurchase_price"	=> formatted_price($qid_items->f("purchase_price")),
+				"prod_qty"		=> $qid_items->f("qty"),
+				"prod_total"		=> $qid_items->f("total"),
+				"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
 		if ($SESSION["weight_used"]) {
 			$t->set_var(array(
-					"prod_purchase_weight"	=> $prod->purchase_weight,
-					"prod_fpurchase_weight"	=> formatted_weight ($prod->purchase_weight)
+					"prod_purchase_weight"	=> $qid_items->f("purchase_weight"),
+					"prod_fpurchase_weight"	=> formatted_weight ($qid_items->f("purchase_weight"))
 			));
 			$t->parse("weight_used_row_blck", "weight_used_row", true);
 		}
 		if ($SESSION["iva_used"]) {
-			$t->set_var("prod_purchase_iva", $prod->purchase_iva);
+			$t->set_var("prod_purchase_iva", $qid_items->f("purchase_iva"));
 			$t->parse("iva_used_row_blck", "iva_used_row", true);
 		}
 		$t->parse("item_rows", "item_row", true);
@@ -192,8 +156,8 @@ function show_order_details($id, $username) {
 	$t->set_var(array("delivery_used_blck" => ""));
 	if ($SESSION["delivery_used"]) {
 		$t->set_var(array(
-				"order_delivery"	=> $order->delivery,
-				"order_fdelivery"	=> formatted_price($order->delivery)
+				"order_delivery"	=> $qid_order->f("delivery"),
+				"order_fdelivery"	=> formatted_price($qid_order->f("delivery"))
 		));
 		$t->parse("delivery_used_blck", "delivery_used", true);
 	}
@@ -212,16 +176,28 @@ function print_order_list($username) {
 //	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
-		$qid = db_query("
-		SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
-		FROM ordersca o, orders_states os
-		WHERE o.state_id = os.id AND username = '$username'
-		ORDER BY os.name, o.id ASC
+		$qid = new DB_Sql;
+//		$qid = db_query("
+		$qid->Query("
+			SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
+			FROM ordersca o, orders_states os
+			WHERE o.state_id = os.id AND username = '$username'
+			ORDER BY os.name, o.id ASC
   		");
 
-		$SESSION["numr"] = db_num_rows($qid);
+//		$SESSION["numr"] = db_num_rows($qid);
+		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-			$SESSION["ordersca"][$i] = db_fetch_array($qid, $i);
+//			$SESSION["ordersca"][$i] = db_fetch_array($qid, $i);
+			$qid->seek($i);
+			$qid->next_record();
+			$SESSION["ordersca"][$i]["id"] = $qid->f("id");
+			$SESSION["ordersca"][$i]["username"] = $qid->f("username");
+			$SESSION["ordersca"][$i]["date"] = $qid->f("date");
+			$SESSION["ordersca"][$i]["custinfo"] = $qid->f("custinfo");
+			$SESSION["ordersca"][$i]["amount"] = $qid->f("amount");
+			$SESSION["ordersca"][$i]["notes"] = $qid->f("notes");
+			$SESSION["ordersca"][$i]["state_name"] = $qid->f("state_name");
 		}
 		if (!isset($page_number)) {
 			$page_number = 1;
